import React, { useState, useEffect } from 'react';
import { Card, Button, Space, message, Tag, Tooltip, Typography } from 'antd';
import { EyeOutlined, PhoneOutlined, DeleteOutlined, DownloadOutlined } from '@ant-design/icons';
import type { ColumnsType } from 'antd/es/table';
import { DataTable, StatusTag, ConfirmDialog } from '@/components/Common';
import { useAppState } from '@/store';
import { apiService } from '@/services/api';
import { formatDateTime, formatDuration, formatCurrency } from '@/utils';
import type { Call, TableParams } from '@/types';

const { Text } = Typography;

const CallList: React.FC = () => {
  const { loading, setLoading } = useAppState();
  const [calls, setCalls] = useState<Call[]>([]);
  const [total, setTotal] = useState(0);
  const [selectedRowKeys, setSelectedRowKeys] = useState<React.Key[]>([]);

  // 获取通话记录列表
  const fetchCalls = async (params?: TableParams) => {
    try {
      setLoading(true);
      const response = await apiService.getCalls(params);
      setCalls(response.data);
      setTotal(response.total);
    } catch (error) {
      message.error('获取通话记录失败');
      console.error('获取通话记录失败:', error);
    } finally {
      setLoading(false);
    }
  };

  // 删除通话记录
  const handleDelete = async (id: string) => {
    ConfirmDialog.delete({
      content: '删除通话记录后将无法恢复，确定要删除吗？',
      onConfirm: async () => {
        try {
          await apiService.deleteCall(id);
          message.success('删除成功');
          fetchCalls();
        } catch (error) {
          message.error('删除失败');
          console.error('删除通话记录失败:', error);
        }
      },
    });
  };

  // 批量删除
  const handleBatchDelete = () => {
    if (selectedRowKeys.length === 0) {
      message.warning('请选择要删除的通话记录');
      return;
    }

    ConfirmDialog.batchDelete(selectedRowKeys.length, {
      onConfirm: async () => {
        try {
          await apiService.batchDeleteCalls(selectedRowKeys as string[]);
          message.success('批量删除成功');
          setSelectedRowKeys([]);
          fetchCalls();
        } catch (error) {
          message.error('批量删除失败');
          console.error('批量删除通话记录失败:', error);
        }
      },
    });
  };

  // 下载录音
  const handleDownloadRecording = async (callId: string, fileName: string) => {
    try {
      const url = await apiService.getCallRecordingUrl(callId);
      const link = document.createElement('a');
      link.href = url;
      link.download = fileName;
      document.body.appendChild(link);
      link.click();
      document.body.removeChild(link);
      message.success('录音下载开始');
    } catch (error) {
      message.error('录音下载失败');
      console.error('下载录音失败:', error);
    }
  };

  // 表格列定义
  const columns: ColumnsType<Call> = [
    {
      title: '通话信息',
      key: 'callInfo',
      width: 200,
      render: (_, record) => (
        <div>
          <div style={{ fontWeight: 'bold', marginBottom: 4 }}>
            <PhoneOutlined style={{ marginRight: 4, color: '#1890ff' }} />
            {record.callId}
          </div>
          <div style={{ fontSize: '12px', color: '#666' }}>
            {record.type === 'video' ? '视频通话' : '语音通话'}
          </div>
        </div>
      ),
    },
    {
      title: '客户信息',
      key: 'client',
      width: 150,
      render: (_, record) => (
        <div>
          <div style={{ fontWeight: 'bold' }}>{record.clientName}</div>
          <div style={{ fontSize: '12px', color: '#666' }}>
            {record.clientPhone}
          </div>
        </div>
      ),
    },
    {
      title: '译员信息',
      key: 'translator',
      width: 150,
      render: (_, record) => (
        <div>
          <div style={{ fontWeight: 'bold' }}>{record.translatorName}</div>
          <div style={{ fontSize: '12px', color: '#666' }}>
            {record.translatorPhone}
          </div>
        </div>
      ),
    },
    {
      title: '语言对',
      key: 'languages',
      width: 120,
      render: (_, record) => (
        <Tag color="blue">
          {record.sourceLanguage} → {record.targetLanguage}
        </Tag>
      ),
    },
    {
      title: '通话时长',
      dataIndex: 'duration',
      key: 'duration',
      width: 100,
      render: (duration: number) => formatDuration(duration),
      sorter: true,
    },
    {
      title: '费用',
      dataIndex: 'cost',
      key: 'cost',
      width: 100,
      render: (cost: number) => (
        <Text strong style={{ color: '#f5222d' }}>
          {formatCurrency(cost)}
        </Text>
      ),
      sorter: true,
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      width: 100,
      render: (status: string) => (
        <StatusTag type="call" status={status} />
      ),
    },
    {
      title: '开始时间',
      dataIndex: 'startTime',
      key: 'startTime',
      width: 150,
      render: (date: string) => formatDateTime(date),
      sorter: true,
    },
    {
      title: '结束时间',
      dataIndex: 'endTime',
      key: 'endTime',
      width: 150,
      render: (date: string) => date ? formatDateTime(date) : '-',
      sorter: true,
    },
    {
      title: '操作',
      key: 'actions',
      width: 120,
      fixed: 'right',
      render: (_, record) => (
        <Space size="small">
          <Tooltip title="查看详情">
            <Button
              type="text"
              icon={<EyeOutlined />}
              onClick={() => handleView(record.id)}
            />
          </Tooltip>
          {record.recordingUrl && (
            <Tooltip title="下载录音">
              <Button
                type="text"
                icon={<DownloadOutlined />}
                onClick={() => handleDownloadRecording(
                  record.id, 
                  `${record.callId}_recording.mp3`
                )}
              />
            </Tooltip>
          )}
          <Tooltip title="删除">
            <Button
              type="text"
              danger
              icon={<DeleteOutlined />}
              onClick={() => handleDelete(record.id)}
            />
          </Tooltip>
        </Space>
      ),
    },
  ];

  // 查看详情
  const handleView = (id: string) => {
    // TODO: 实现查看详情功能
    console.log('查看通话详情:', id);
  };

  useEffect(() => {
    fetchCalls();
  }, []);

  return (
    <Card>
      <div style={{ marginBottom: 16 }}>
        <Space>
          <Button 
            danger 
            disabled={selectedRowKeys.length === 0}
            onClick={handleBatchDelete}
          >
            批量删除 ({selectedRowKeys.length})
          </Button>
        </Space>
      </div>

      <DataTable
        columns={columns}
        dataSource={calls}
        loading={loading}
        pagination={{
          total,
          showSizeChanger: true,
          showQuickJumper: true,
          showTotal: (total, range) => 
            `第 ${range[0]}-${range[1]} 条，共 ${total} 条`,
        }}
        rowSelection={{
          selectedRowKeys,
          onChange: setSelectedRowKeys,
        }}
        searchable
        filterable
        onTableChange={fetchCalls}
        scroll={{ x: 1200 }}
      />
    </Card>
  );
};

export default CallList; 