import React, { useState, useEffect } from 'react';
import {
  View,
  Text,
  StyleSheet,
  TouchableOpacity,
  ScrollView,
  SafeAreaView,
  Alert,
  Modal,
  TextInput,
} from 'react-native';
import { mockAppointments, mockLanguages } from '@/utils/mockData';
import { Appointment, Language } from '@/types';

interface AppointmentScreenProps {
  navigation?: any;
}

const AppointmentScreen: React.FC<AppointmentScreenProps> = ({ navigation }) => {
  const [appointments, setAppointments] = useState<Appointment[]>([]);
  const [selectedDate, setSelectedDate] = useState(new Date());
  const [createModalVisible, setCreateModalVisible] = useState(false);
  const [newAppointment, setNewAppointment] = useState({
    title: '',
    description: '',
    date: new Date(),
    time: '09:00',
    duration: 60,
    mode: 'human' as 'ai' | 'human' | 'video' | 'sign',
    sourceLanguage: 'zh',
    targetLanguage: 'en',
  });

  useEffect(() => {
    loadAppointments();
  }, []);

  const loadAppointments = async () => {
    try {
      // 模拟API调用
      setTimeout(() => {
        setAppointments(mockAppointments);
      }, 500);
    } catch (error) {
      console.error('Failed to load appointments:', error);
    }
  };

  const getLanguageInfo = (code: string): Language | undefined => {
    return mockLanguages.find(lang => lang.code === code);
  };

  const formatDate = (date: Date | string): string => {
    const d = new Date(date);
    return d.toLocaleDateString('zh-CN', {
      month: 'short',
      day: 'numeric',
      weekday: 'short',
    });
  };

  const formatTime = (date: Date | string): string => {
    const d = new Date(date);
    return d.toLocaleTimeString('zh-CN', {
      hour: '2-digit',
      minute: '2-digit',
    });
  };

  const getStatusColor = (status: string): string => {
    const colorMap: { [key: string]: string } = {
      scheduled: '#2196F3',
      confirmed: '#4CAF50',
      cancelled: '#F44336',
      completed: '#9E9E9E',
    };
    return colorMap[status] || '#999';
  };

  const getStatusText = (status: string): string => {
    const textMap: { [key: string]: string } = {
      scheduled: '已预约',
      confirmed: '已确认',
      cancelled: '已取消',
      completed: '已完成',
    };
    return textMap[status] || status;
  };

  const getModeText = (mode: string): string => {
    const modeMap: { [key: string]: string } = {
      ai: 'AI翻译',
      human: '人工翻译',
      video: '视频翻译',
      sign: '手语翻译',
    };
    return modeMap[mode] || mode;
  };

  const getModeIcon = (mode: string): string => {
    const iconMap: { [key: string]: string } = {
      ai: '🤖',
      human: '👥',
      video: '📹',
      sign: '🤟',
    };
    return iconMap[mode] || '📞';
  };

  const handleCreateAppointment = () => {
    setCreateModalVisible(true);
  };

  const handleSaveAppointment = () => {
    if (!newAppointment.title.trim()) {
      Alert.alert('错误', '请输入预约标题');
      return;
    }

    const appointment: Appointment = {
      id: `appointment-${Date.now()}`,
      userId: 'user-123',
      title: newAppointment.title,
      description: newAppointment.description,
      startTime: new Date(`${newAppointment.date.toDateString()} ${newAppointment.time}`).toISOString(),
      endTime: new Date(
        new Date(`${newAppointment.date.toDateString()} ${newAppointment.time}`).getTime() + 
        newAppointment.duration * 60 * 1000
      ).toISOString(),
      mode: newAppointment.mode,
      sourceLanguage: newAppointment.sourceLanguage,
      targetLanguage: newAppointment.targetLanguage,
      status: 'scheduled',
      createdAt: new Date().toISOString(),
    };

    setAppointments(prev => [appointment, ...prev]);
    setCreateModalVisible(false);
    resetNewAppointment();
    Alert.alert('成功', '预约已创建');
  };

  const resetNewAppointment = () => {
    setNewAppointment({
      title: '',
      description: '',
      date: new Date(),
      time: '09:00',
      duration: 60,
      mode: 'human',
      sourceLanguage: 'zh',
      targetLanguage: 'en',
    });
  };

  const handleCancelAppointment = (appointment: Appointment) => {
    Alert.alert(
      '取消预约',
      `确定要取消预约"${appointment.title}"吗？`,
      [
        { text: '否', style: 'cancel' },
        {
          text: '是',
          style: 'destructive',
          onPress: () => {
            setAppointments(prev =>
              prev.map(apt =>
                apt.id === appointment.id
                  ? { ...apt, status: 'cancelled' }
                  : apt
              )
            );
          }
        },
      ]
    );
  };

  const handleJoinAppointment = (appointment: Appointment) => {
    if (appointment.status !== 'confirmed') {
      Alert.alert('无法加入', '预约尚未确认');
      return;
    }

    const now = new Date();
    const startTime = new Date(appointment.startTime);
    const timeDiff = startTime.getTime() - now.getTime();
    const minutesDiff = Math.floor(timeDiff / (1000 * 60));

    if (minutesDiff > 15) {
      Alert.alert('提醒', `距离预约开始还有${minutesDiff}分钟`);
      return;
    }

    // 导航到通话屏幕
    navigation?.navigate('Call', {
      mode: appointment.mode,
      sourceLanguage: appointment.sourceLanguage,
      targetLanguage: appointment.targetLanguage,
    });
  };

  const renderCalendarHeader = () => {
    const today = new Date();
    const currentMonth = today.toLocaleDateString('zh-CN', { 
      year: 'numeric', 
      month: 'long' 
    });

    return (
      <View style={styles.calendarHeader}>
        <Text style={styles.monthText}>{currentMonth}</Text>
        <TouchableOpacity style={styles.todayButton}>
          <Text style={styles.todayButtonText}>今天</Text>
        </TouchableOpacity>
      </View>
    );
  };

  const renderAppointmentItem = (appointment: Appointment) => {
    const sourceLang = getLanguageInfo(appointment.sourceLanguage);
    const targetLang = getLanguageInfo(appointment.targetLanguage);
    const isUpcoming = new Date(appointment.startTime) > new Date();
    const canJoin = appointment.status === 'confirmed' && isUpcoming;

    return (
      <View key={appointment.id} style={styles.appointmentItem}>
        <View style={styles.appointmentHeader}>
          <View style={styles.appointmentTime}>
            <Text style={styles.timeText}>{formatTime(appointment.startTime)}</Text>
            <Text style={styles.dateText}>{formatDate(appointment.startTime)}</Text>
          </View>
          <View style={[styles.statusBadge, { backgroundColor: getStatusColor(appointment.status) }]}>
            <Text style={styles.statusText}>{getStatusText(appointment.status)}</Text>
          </View>
        </View>

        <View style={styles.appointmentContent}>
          <View style={styles.appointmentInfo}>
            <Text style={styles.appointmentTitle}>{appointment.title}</Text>
            {appointment.description && (
              <Text style={styles.appointmentDescription}>{appointment.description}</Text>
            )}
            <View style={styles.appointmentDetails}>
              <Text style={styles.modeText}>
                {getModeIcon(appointment.mode)} {getModeText(appointment.mode)}
              </Text>
              <Text style={styles.languageText}>
                {sourceLang?.flag} {sourceLang?.nativeName} → {targetLang?.flag} {targetLang?.nativeName}
              </Text>
            </View>
          </View>
        </View>

        <View style={styles.appointmentActions}>
          {canJoin && (
            <TouchableOpacity
              style={[styles.actionButton, styles.joinButton]}
              onPress={() => handleJoinAppointment(appointment)}
            >
              <Text style={styles.actionButtonText}>加入</Text>
            </TouchableOpacity>
          )}
          {appointment.status === 'scheduled' && (
            <TouchableOpacity
              style={[styles.actionButton, styles.cancelButton]}
              onPress={() => handleCancelAppointment(appointment)}
            >
              <Text style={styles.actionButtonText}>取消</Text>
            </TouchableOpacity>
          )}
        </View>
      </View>
    );
  };

  const renderCreateModal = () => (
    <Modal
      visible={createModalVisible}
      transparent
      animationType="slide"
      onRequestClose={() => setCreateModalVisible(false)}
    >
      <View style={styles.modalOverlay}>
        <View style={styles.modalContent}>
          <Text style={styles.modalTitle}>创建预约</Text>

          <View style={styles.formGroup}>
            <Text style={styles.formLabel}>标题</Text>
            <TextInput
              style={styles.textInput}
              value={newAppointment.title}
              onChangeText={(text) => setNewAppointment(prev => ({ ...prev, title: text }))}
              placeholder="输入预约标题"
            />
          </View>

          <View style={styles.formGroup}>
            <Text style={styles.formLabel}>描述</Text>
            <TextInput
              style={[styles.textInput, styles.textArea]}
              value={newAppointment.description}
              onChangeText={(text) => setNewAppointment(prev => ({ ...prev, description: text }))}
              placeholder="输入预约描述（可选）"
              multiline
              numberOfLines={3}
            />
          </View>

          <View style={styles.formRow}>
            <View style={styles.formGroup}>
              <Text style={styles.formLabel}>日期</Text>
              <TouchableOpacity style={styles.dateButton}>
                <Text style={styles.dateButtonText}>
                  {newAppointment.date.toLocaleDateString('zh-CN')}
                </Text>
              </TouchableOpacity>
            </View>
            <View style={styles.formGroup}>
              <Text style={styles.formLabel}>时间</Text>
              <TouchableOpacity style={styles.timeButton}>
                <Text style={styles.timeButtonText}>{newAppointment.time}</Text>
              </TouchableOpacity>
            </View>
          </View>

          <View style={styles.formGroup}>
            <Text style={styles.formLabel}>翻译模式</Text>
            <View style={styles.modeSelector}>
              {[
                { key: 'human', label: '人工翻译', icon: '👥' },
                { key: 'ai', label: 'AI翻译', icon: '🤖' },
                { key: 'video', label: '视频翻译', icon: '📹' },
                { key: 'sign', label: '手语翻译', icon: '🤟' },
              ].map((mode) => (
                <TouchableOpacity
                  key={mode.key}
                  style={[
                    styles.modeOption,
                    newAppointment.mode === mode.key && styles.modeOptionSelected
                  ]}
                  onPress={() => setNewAppointment(prev => ({ ...prev, mode: mode.key as any }))}
                >
                  <Text style={styles.modeIcon}>{mode.icon}</Text>
                  <Text style={styles.modeLabel}>{mode.label}</Text>
                </TouchableOpacity>
              ))}
            </View>
          </View>

          <View style={styles.formGroup}>
            <Text style={styles.formLabel}>语言设置</Text>
            <View style={styles.languageRow}>
              <View style={styles.languageOption}>
                <Text style={styles.languageLabel}>源语言</Text>
                <TouchableOpacity style={styles.languageButton}>
                  <Text style={styles.languageButtonText}>
                    {getLanguageInfo(newAppointment.sourceLanguage)?.nativeName || '中文'}
                  </Text>
                </TouchableOpacity>
              </View>
              <Text style={styles.arrowText}>→</Text>
              <View style={styles.languageOption}>
                <Text style={styles.languageLabel}>目标语言</Text>
                <TouchableOpacity style={styles.languageButton}>
                  <Text style={styles.languageButtonText}>
                    {getLanguageInfo(newAppointment.targetLanguage)?.nativeName || 'English'}
                  </Text>
                </TouchableOpacity>
              </View>
            </View>
          </View>

          <View style={styles.modalActions}>
            <TouchableOpacity
              style={[styles.modalButton, styles.cancelModalButton]}
              onPress={() => setCreateModalVisible(false)}
            >
              <Text style={styles.cancelModalButtonText}>取消</Text>
            </TouchableOpacity>
            <TouchableOpacity
              style={[styles.modalButton, styles.saveButton]}
              onPress={handleSaveAppointment}
            >
              <Text style={styles.saveButtonText}>保存</Text>
            </TouchableOpacity>
          </View>
        </View>
      </View>
    </Modal>
  );

  return (
    <SafeAreaView style={styles.container}>
      <View style={styles.header}>
        <Text style={styles.headerTitle}>预约管理</Text>
        <TouchableOpacity style={styles.createButton} onPress={handleCreateAppointment}>
          <Text style={styles.createButtonText}>+ 创建</Text>
        </TouchableOpacity>
      </View>

      {renderCalendarHeader()}

      <ScrollView style={styles.content} showsVerticalScrollIndicator={false}>
        {appointments.length === 0 ? (
          <View style={styles.emptyContainer}>
            <Text style={styles.emptyIcon}>📅</Text>
            <Text style={styles.emptyTitle}>暂无预约</Text>
            <Text style={styles.emptySubtitle}>创建您的第一个预约</Text>
            <TouchableOpacity style={styles.emptyButton} onPress={handleCreateAppointment}>
              <Text style={styles.emptyButtonText}>创建预约</Text>
            </TouchableOpacity>
          </View>
        ) : (
          <View style={styles.appointmentList}>
            {appointments.map(renderAppointmentItem)}
          </View>
        )}
      </ScrollView>

      {renderCreateModal()}
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#f5f5f5',
  },
  header: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    padding: 16,
    backgroundColor: '#fff',
    borderBottomWidth: 1,
    borderBottomColor: '#e0e0e0',
  },
  headerTitle: {
    fontSize: 20,
    fontWeight: 'bold',
    color: '#333',
  },
  createButton: {
    backgroundColor: '#2196F3',
    paddingHorizontal: 16,
    paddingVertical: 8,
    borderRadius: 20,
  },
  createButtonText: {
    color: '#fff',
    fontSize: 14,
    fontWeight: 'bold',
  },
  calendarHeader: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    padding: 16,
    backgroundColor: '#fff',
    borderBottomWidth: 1,
    borderBottomColor: '#f0f0f0',
  },
  monthText: {
    fontSize: 18,
    fontWeight: 'bold',
    color: '#333',
  },
  todayButton: {
    backgroundColor: '#f0f0f0',
    paddingHorizontal: 12,
    paddingVertical: 6,
    borderRadius: 16,
  },
  todayButtonText: {
    color: '#666',
    fontSize: 12,
  },
  content: {
    flex: 1,
    padding: 16,
  },
  emptyContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    paddingTop: 100,
  },
  emptyIcon: {
    fontSize: 80,
    marginBottom: 16,
  },
  emptyTitle: {
    fontSize: 20,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 8,
  },
  emptySubtitle: {
    fontSize: 16,
    color: '#666',
    marginBottom: 32,
  },
  emptyButton: {
    backgroundColor: '#2196F3',
    paddingHorizontal: 32,
    paddingVertical: 12,
    borderRadius: 24,
  },
  emptyButtonText: {
    color: '#fff',
    fontSize: 16,
    fontWeight: 'bold',
  },
  appointmentList: {
    gap: 16,
  },
  appointmentItem: {
    backgroundColor: '#fff',
    borderRadius: 12,
    padding: 16,
    shadowColor: '#000',
    shadowOffset: { width: 0, height: 2 },
    shadowOpacity: 0.1,
    shadowRadius: 4,
    elevation: 3,
  },
  appointmentHeader: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'flex-start',
    marginBottom: 12,
  },
  appointmentTime: {
    alignItems: 'flex-start',
  },
  timeText: {
    fontSize: 18,
    fontWeight: 'bold',
    color: '#333',
  },
  dateText: {
    fontSize: 12,
    color: '#666',
    marginTop: 2,
  },
  statusBadge: {
    paddingHorizontal: 8,
    paddingVertical: 4,
    borderRadius: 12,
  },
  statusText: {
    color: '#fff',
    fontSize: 12,
    fontWeight: 'bold',
  },
  appointmentContent: {
    marginBottom: 12,
  },
  appointmentInfo: {
    flex: 1,
  },
  appointmentTitle: {
    fontSize: 16,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 4,
  },
  appointmentDescription: {
    fontSize: 14,
    color: '#666',
    marginBottom: 8,
  },
  appointmentDetails: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
  },
  modeText: {
    fontSize: 12,
    color: '#666',
  },
  languageText: {
    fontSize: 12,
    color: '#666',
  },
  appointmentActions: {
    flexDirection: 'row',
    justifyContent: 'flex-end',
  },
  actionButton: {
    paddingHorizontal: 16,
    paddingVertical: 8,
    borderRadius: 16,
    marginLeft: 8,
  },
  joinButton: {
    backgroundColor: '#4CAF50',
  },
  cancelButton: {
    backgroundColor: '#F44336',
  },
  actionButtonText: {
    color: '#fff',
    fontSize: 12,
    fontWeight: 'bold',
  },
  modalOverlay: {
    flex: 1,
    backgroundColor: 'rgba(0, 0, 0, 0.5)',
    justifyContent: 'center',
    alignItems: 'center',
  },
  modalContent: {
    backgroundColor: '#fff',
    borderRadius: 16,
    padding: 24,
    width: '90%',
    maxWidth: 400,
    maxHeight: '80%',
  },
  modalTitle: {
    fontSize: 20,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 24,
    textAlign: 'center',
  },
  formGroup: {
    marginBottom: 16,
  },
  formRow: {
    flexDirection: 'row',
    gap: 12,
  },
  formLabel: {
    fontSize: 14,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 8,
  },
  textInput: {
    borderWidth: 1,
    borderColor: '#e0e0e0',
    borderRadius: 8,
    padding: 12,
    fontSize: 14,
    color: '#333',
  },
  textArea: {
    height: 80,
    textAlignVertical: 'top',
  },
  dateButton: {
    borderWidth: 1,
    borderColor: '#e0e0e0',
    borderRadius: 8,
    padding: 12,
    alignItems: 'center',
  },
  dateButtonText: {
    fontSize: 14,
    color: '#333',
  },
  timeButton: {
    borderWidth: 1,
    borderColor: '#e0e0e0',
    borderRadius: 8,
    padding: 12,
    alignItems: 'center',
  },
  timeButtonText: {
    fontSize: 14,
    color: '#333',
  },
  modeSelector: {
    flexDirection: 'row',
    flexWrap: 'wrap',
    gap: 8,
  },
  modeOption: {
    flex: 1,
    minWidth: '45%',
    borderWidth: 1,
    borderColor: '#e0e0e0',
    borderRadius: 8,
    padding: 12,
    alignItems: 'center',
  },
  modeOptionSelected: {
    borderColor: '#2196F3',
    backgroundColor: '#E3F2FD',
  },
  modeIcon: {
    fontSize: 24,
    marginBottom: 4,
  },
  modeLabel: {
    fontSize: 12,
    color: '#333',
  },
  languageRow: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
  },
  languageOption: {
    flex: 1,
  },
  languageLabel: {
    fontSize: 12,
    color: '#666',
    marginBottom: 4,
  },
  languageButton: {
    backgroundColor: '#f0f0f0',
    padding: 12,
    borderRadius: 8,
    alignItems: 'center',
  },
  languageButtonText: {
    fontSize: 14,
    color: '#333',
  },
  arrowText: {
    fontSize: 20,
    color: '#666',
    marginHorizontal: 16,
  },
  modalActions: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    marginTop: 24,
  },
  modalButton: {
    flex: 1,
    paddingVertical: 12,
    borderRadius: 24,
    alignItems: 'center',
    marginHorizontal: 8,
  },
  cancelModalButton: {
    backgroundColor: '#f0f0f0',
  },
  cancelModalButtonText: {
    color: '#666',
    fontSize: 14,
    fontWeight: 'bold',
  },
  saveButton: {
    backgroundColor: '#2196F3',
  },
  saveButtonText: {
    color: '#fff',
    fontSize: 14,
    fontWeight: 'bold',
  },
});

export default AppointmentScreen; 