import React, { useState, useEffect, useRef } from 'react';
import {
  View,
  Text,
  StyleSheet,
  TouchableOpacity,
  Alert,
  SafeAreaView,
  Dimensions,
  StatusBar,
} from 'react-native';
import { mockLanguages } from '@/utils/mockData';
import { Language, CallSession } from '@/types';

const { width, height } = Dimensions.get('window');

interface CallScreenProps {
  route?: {
    params?: {
      mode: 'ai' | 'human' | 'video' | 'sign';
      sourceLanguage: string;
      targetLanguage: string;
    };
  };
  navigation?: any;
}

const CallScreen: React.FC<CallScreenProps> = ({ route, navigation }) => {
  const [isConnected, setIsConnected] = useState(false);
  const [isConnecting, setIsConnecting] = useState(true);
  const [isMuted, setIsMuted] = useState(false);
  const [isVideoEnabled, setIsVideoEnabled] = useState(true);
  const [callDuration, setCallDuration] = useState(0);
  const [currentCall, setCurrentCall] = useState<CallSession | null>(null);
  
  const callTimer = useRef<NodeJS.Timeout | null>(null);
  const startTime = useRef<Date | null>(null);

  // 从路由参数获取通话配置
  const callMode = route?.params?.mode || 'ai';
  const sourceLanguage = route?.params?.sourceLanguage || 'zh';
  const targetLanguage = route?.params?.targetLanguage || 'en';

  // 获取语言信息
  const getLanguageInfo = (code: string): Language | undefined => {
    return mockLanguages.find(lang => lang.code === code);
  };

  const sourceLang = getLanguageInfo(sourceLanguage);
  const targetLang = getLanguageInfo(targetLanguage);

  useEffect(() => {
    // 模拟连接过程
    connectToCall();
    
    return () => {
      if (callTimer.current) {
        clearInterval(callTimer.current);
      }
    };
  }, []);

  const connectToCall = async () => {
    try {
      setIsConnecting(true);
      
      // 模拟获取Twilio token和连接过程
      // const tokenResponse = await apiService.getTwilioToken(callMode);
      // const callResponse = await apiService.startCall({
      //   mode: callMode,
      //   sourceLanguage,
      //   targetLanguage,
      // });
      
      // 模拟连接延迟
      setTimeout(() => {
        setIsConnecting(false);
        setIsConnected(true);
        startCallTimer();
        
        // 创建模拟通话会话
        const mockCall: CallSession = {
          id: `call-${Date.now()}`,
          userId: 'user-123',
          mode: callMode,
          sourceLanguage,
          targetLanguage,
          status: 'active',
          duration: 0,
          cost: 0,
          twilioRoomId: `room-${Date.now()}`,
          createdAt: new Date().toISOString(),
        };
        setCurrentCall(mockCall);
      }, 2000);
      
    } catch (error) {
      console.error('Failed to connect to call:', error);
      Alert.alert('连接失败', '无法建立通话连接，请重试。');
      navigation?.goBack();
    }
  };

  const startCallTimer = () => {
    startTime.current = new Date();
    callTimer.current = setInterval(() => {
      if (startTime.current) {
        const elapsed = Math.floor((Date.now() - startTime.current.getTime()) / 1000);
        setCallDuration(elapsed);
      }
    }, 1000);
  };

  const formatDuration = (seconds: number): string => {
    const mins = Math.floor(seconds / 60);
    const secs = seconds % 60;
    return `${mins.toString().padStart(2, '0')}:${secs.toString().padStart(2, '0')}`;
  };

  const handleEndCall = () => {
    Alert.alert(
      '结束通话',
      '确定要结束当前通话吗？',
      [
        { text: '取消', style: 'cancel' },
        { 
          text: '结束', 
          style: 'destructive',
          onPress: () => {
            endCall();
          }
        },
      ]
    );
  };

  const endCall = async () => {
    try {
      if (callTimer.current) {
        clearInterval(callTimer.current);
      }
      
      // 在实际应用中调用API结束通话
      // if (currentCall) {
      //   await apiService.endCall(currentCall.id, callDuration);
      // }
      
      setIsConnected(false);
      navigation?.goBack();
    } catch (error) {
      console.error('Failed to end call:', error);
      navigation?.goBack();
    }
  };

  const toggleMute = () => {
    setIsMuted(!isMuted);
    // 在实际应用中控制音频
    // twilioRoom?.localParticipant?.audioTracks?.forEach(track => {
    //   track.enable(!isMuted);
    // });
  };

  const toggleVideo = () => {
    if (callMode === 'video' || callMode === 'sign') {
      setIsVideoEnabled(!isVideoEnabled);
      // 在实际应用中控制视频
      // twilioRoom?.localParticipant?.videoTracks?.forEach(track => {
      //   track.enable(!isVideoEnabled);
      // });
    }
  };

  const getModeTitle = (mode: string): string => {
    const modeMap: { [key: string]: string } = {
      ai: 'AI翻译通话',
      human: '人工翻译通话',
      video: '视频翻译通话',
      sign: '手语翻译通话',
    };
    return modeMap[mode] || '通话中';
  };

  const getModeIcon = (mode: string): string => {
    const iconMap: { [key: string]: string } = {
      ai: '🤖',
      human: '👥',
      video: '📹',
      sign: '🤟',
    };
    return iconMap[mode] || '📞';
  };

  if (isConnecting) {
    return (
      <SafeAreaView style={styles.container}>
        <StatusBar barStyle="light-content" backgroundColor="#1a1a1a" />
        <View style={styles.connectingContainer}>
          <Text style={styles.connectingIcon}>📞</Text>
          <Text style={styles.connectingTitle}>正在连接...</Text>
          <Text style={styles.connectingSubtitle}>
            {getModeTitle(callMode)}
          </Text>
          <View style={styles.languageInfo}>
            <Text style={styles.languageText}>
              {sourceLang?.flag} {sourceLang?.nativeName} → {targetLang?.flag} {targetLang?.nativeName}
            </Text>
          </View>
          <TouchableOpacity style={styles.cancelButton} onPress={() => navigation?.goBack()}>
            <Text style={styles.cancelButtonText}>取消</Text>
          </TouchableOpacity>
        </View>
      </SafeAreaView>
    );
  }

  return (
    <SafeAreaView style={styles.container}>
      <StatusBar barStyle="light-content" backgroundColor="#1a1a1a" />
      
      {/* 顶部信息栏 */}
      <View style={styles.topBar}>
        <View style={styles.callInfo}>
          <Text style={styles.modeIcon}>{getModeIcon(callMode)}</Text>
          <View style={styles.callDetails}>
            <Text style={styles.callTitle}>{getModeTitle(callMode)}</Text>
            <Text style={styles.languagesText}>
              {sourceLang?.nativeName} → {targetLang?.nativeName}
            </Text>
          </View>
        </View>
        <Text style={styles.duration}>{formatDuration(callDuration)}</Text>
      </View>

      {/* 视频区域 */}
      <View style={styles.videoContainer}>
        {(callMode === 'video' || callMode === 'sign') ? (
          <View style={styles.videoArea}>
            <View style={styles.remoteVideo}>
              <Text style={styles.videoPlaceholder}>
                {callMode === 'sign' ? '手语翻译员' : '翻译员视频'}
              </Text>
            </View>
            <View style={styles.localVideo}>
              <Text style={styles.videoPlaceholder}>您的视频</Text>
            </View>
          </View>
        ) : (
          <View style={styles.audioOnlyArea}>
            <Text style={styles.audioIcon}>
              {callMode === 'ai' ? '🤖' : '👥'}
            </Text>
            <Text style={styles.audioTitle}>
              {callMode === 'ai' ? 'AI翻译中...' : '人工翻译中...'}
            </Text>
            <View style={styles.waveform}>
              {[1, 2, 3, 4, 5].map((i) => (
                <View key={i} style={[styles.waveBar, { height: Math.random() * 40 + 10 }]} />
              ))}
            </View>
          </View>
        )}
      </View>

      {/* 控制按钮 */}
      <View style={styles.controlsContainer}>
        <TouchableOpacity
          style={[styles.controlButton, isMuted && styles.controlButtonActive]}
          onPress={toggleMute}
        >
          <Text style={styles.controlButtonText}>
            {isMuted ? '🔇' : '🔊'}
          </Text>
        </TouchableOpacity>

        {(callMode === 'video' || callMode === 'sign') && (
          <TouchableOpacity
            style={[styles.controlButton, !isVideoEnabled && styles.controlButtonActive]}
            onPress={toggleVideo}
          >
            <Text style={styles.controlButtonText}>
              {isVideoEnabled ? '📹' : '📵'}
            </Text>
          </TouchableOpacity>
        )}

        <TouchableOpacity
          style={[styles.controlButton, styles.endCallButton]}
          onPress={handleEndCall}
        >
          <Text style={styles.controlButtonText}>📞</Text>
        </TouchableOpacity>
      </View>
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#1a1a1a',
  },
  connectingContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    padding: 32,
  },
  connectingIcon: {
    fontSize: 80,
    marginBottom: 24,
  },
  connectingTitle: {
    fontSize: 24,
    fontWeight: 'bold',
    color: '#fff',
    marginBottom: 8,
    textAlign: 'center',
  },
  connectingSubtitle: {
    fontSize: 16,
    color: '#ccc',
    marginBottom: 32,
    textAlign: 'center',
  },
  languageInfo: {
    backgroundColor: 'rgba(255, 255, 255, 0.1)',
    padding: 16,
    borderRadius: 12,
    marginBottom: 32,
  },
  languageText: {
    fontSize: 18,
    color: '#fff',
    textAlign: 'center',
  },
  cancelButton: {
    backgroundColor: '#F44336',
    paddingHorizontal: 32,
    paddingVertical: 12,
    borderRadius: 24,
  },
  cancelButtonText: {
    color: '#fff',
    fontSize: 16,
    fontWeight: 'bold',
  },
  topBar: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    padding: 16,
    backgroundColor: 'rgba(0, 0, 0, 0.3)',
  },
  callInfo: {
    flexDirection: 'row',
    alignItems: 'center',
  },
  modeIcon: {
    fontSize: 32,
    marginRight: 12,
  },
  callDetails: {
    flex: 1,
  },
  callTitle: {
    fontSize: 16,
    fontWeight: 'bold',
    color: '#fff',
    marginBottom: 2,
  },
  languagesText: {
    fontSize: 14,
    color: '#ccc',
  },
  duration: {
    fontSize: 18,
    fontWeight: 'bold',
    color: '#4CAF50',
  },
  videoContainer: {
    flex: 1,
  },
  videoArea: {
    flex: 1,
    position: 'relative',
  },
  remoteVideo: {
    flex: 1,
    backgroundColor: '#333',
    justifyContent: 'center',
    alignItems: 'center',
  },
  localVideo: {
    position: 'absolute',
    top: 16,
    right: 16,
    width: 120,
    height: 160,
    backgroundColor: '#555',
    borderRadius: 8,
    justifyContent: 'center',
    alignItems: 'center',
  },
  videoPlaceholder: {
    color: '#ccc',
    fontSize: 16,
    textAlign: 'center',
  },
  audioOnlyArea: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
  },
  audioIcon: {
    fontSize: 120,
    marginBottom: 24,
  },
  audioTitle: {
    fontSize: 20,
    fontWeight: 'bold',
    color: '#fff',
    marginBottom: 32,
    textAlign: 'center',
  },
  waveform: {
    flexDirection: 'row',
    alignItems: 'flex-end',
    height: 60,
  },
  waveBar: {
    width: 4,
    backgroundColor: '#4CAF50',
    marginHorizontal: 2,
    borderRadius: 2,
  },
  controlsContainer: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    padding: 32,
    backgroundColor: 'rgba(0, 0, 0, 0.3)',
  },
  controlButton: {
    width: 64,
    height: 64,
    borderRadius: 32,
    backgroundColor: 'rgba(255, 255, 255, 0.2)',
    justifyContent: 'center',
    alignItems: 'center',
    marginHorizontal: 16,
  },
  controlButtonActive: {
    backgroundColor: '#F44336',
  },
  controlButtonText: {
    fontSize: 24,
  },
  endCallButton: {
    backgroundColor: '#F44336',
  },
});

export default CallScreen; 