import { FC, useState } from 'react';

const DocumentScreen: FC = () => {
  const [selectedFile, setSelectedFile] = useState<File | null>(null);
  const [uploadProgress, setUploadProgress] = useState(0);
  const [isUploading, setIsUploading] = useState(false);

  const handleFileSelect = (event: React.ChangeEvent<HTMLInputElement>) => {
    const file = event.target.files?.[0];
    if (file) {
      setSelectedFile(file);
    }
  };

  const handleUpload = () => {
    if (!selectedFile) return;
    
    setIsUploading(true);
    setUploadProgress(0);
    
    // 模拟上传进度
    const interval = setInterval(() => {
      setUploadProgress(prev => {
        if (prev >= 100) {
          clearInterval(interval);
          setIsUploading(false);
          alert('文档上传成功！');
          return 100;
        }
        return prev + 10;
      });
    }, 200);
  };

  const mockDocuments = [
    {
      id: 1,
      name: '商务合同.pdf',
      status: '已翻译',
      date: '2024-01-15',
      languages: '中文 → 英文',
      size: '2.3 MB'
    },
    {
      id: 2,
      name: '技术文档.docx',
      status: '翻译中',
      date: '2024-01-14',
      languages: '英文 → 中文',
      size: '1.8 MB'
    },
    {
      id: 3,
      name: '法律文件.pdf',
      status: '待翻译',
      date: '2024-01-13',
      languages: '中文 → 法文',
      size: '3.1 MB'
    },
  ];

  return (
    <div style={styles.container}>
      <div style={styles.content}>
        {/* 上传区域 */}
        <div style={styles.uploadSection}>
          <h3 style={styles.sectionTitle}>上传文档</h3>
          <div style={styles.uploadArea}>
            <input
              type="file"
              onChange={handleFileSelect}
              accept=".pdf,.doc,.docx,.txt"
              style={styles.fileInput}
              id="file-upload"
            />
            <label htmlFor="file-upload" style={styles.uploadLabel}>
              <div style={styles.uploadIcon}>📄</div>
              <div style={styles.uploadText}>
                {selectedFile ? selectedFile.name : '点击选择文件或拖拽到此处'}
              </div>
              <div style={styles.uploadSubtext}>
                支持 PDF、Word、TXT 格式，最大 10MB
              </div>
            </label>
          </div>

          {selectedFile && (
            <div style={styles.fileInfo}>
              <div style={styles.fileName}>{selectedFile.name}</div>
              <div style={styles.fileSize}>
                {(selectedFile.size / (1024 * 1024)).toFixed(2)} MB
              </div>
            </div>
          )}

          {isUploading && (
            <div style={styles.progressContainer}>
              <div style={styles.progressBar}>
                <div 
                  style={{
                    ...styles.progressFill,
                    width: `${uploadProgress}%`
                  }}
                />
              </div>
              <div style={styles.progressText}>{uploadProgress}%</div>
            </div>
          )}

          <button 
            style={{
              ...styles.uploadButton,
              backgroundColor: selectedFile && !isUploading ? '#52c41a' : '#d9d9d9',
              cursor: selectedFile && !isUploading ? 'pointer' : 'not-allowed'
            }}
            onClick={handleUpload}
            disabled={!selectedFile || isUploading}
          >
            {isUploading ? '上传中...' : '开始翻译'}
          </button>
        </div>

        {/* 语言选择 */}
        <div style={styles.languageSection}>
          <h3 style={styles.sectionTitle}>翻译设置</h3>
          <div style={styles.languageOptions}>
            <select style={styles.languageSelect}>
              <option value="zh">中文</option>
              <option value="en">英文</option>
              <option value="es">西班牙文</option>
              <option value="fr">法文</option>
              <option value="ja">日文</option>
            </select>
            <span style={styles.arrow}>→</span>
            <select style={styles.languageSelect}>
              <option value="en">英文</option>
              <option value="zh">中文</option>
              <option value="es">西班牙文</option>
              <option value="fr">法文</option>
              <option value="ja">日文</option>
            </select>
          </div>
        </div>

        {/* 文档列表 */}
        <div style={styles.documentsSection}>
          <h3 style={styles.sectionTitle}>我的文档</h3>
          <div style={styles.documentsList}>
            {mockDocuments.map((doc) => (
              <div key={doc.id} style={styles.documentItem}>
                <div style={styles.documentIcon}>📄</div>
                <div style={styles.documentInfo}>
                  <div style={styles.documentName}>{doc.name}</div>
                  <div style={styles.documentMeta}>
                    <span style={styles.documentLanguages}>{doc.languages}</span>
                    <span style={styles.documentSize}>{doc.size}</span>
                  </div>
                  <div style={styles.documentDate}>{doc.date}</div>
                </div>
                <div style={{
                  ...styles.documentStatus,
                  backgroundColor: 
                    doc.status === '已翻译' ? '#f6ffed' :
                    doc.status === '翻译中' ? '#fff7e6' : '#fff1f0',
                  color:
                    doc.status === '已翻译' ? '#52c41a' :
                    doc.status === '翻译中' ? '#fa8c16' : '#ff4d4f'
                }}>
                  {doc.status}
                </div>
              </div>
            ))}
          </div>
        </div>
      </div>
    </div>
  );
};

const styles = {
  container: {
    display: 'flex',
    flexDirection: 'column' as const,
    height: '100%',
    backgroundColor: '#f5f5f5',
  },
  content: {
    flex: 1,
    padding: '16px',
    paddingBottom: '100px',
  },
  uploadSection: {
    marginBottom: '24px',
  },
  sectionTitle: {
    fontSize: '18px',
    fontWeight: 'bold',
    color: '#333',
    margin: '0 0 16px 0',
  },
  uploadArea: {
    position: 'relative' as const,
    marginBottom: '16px',
  },
  fileInput: {
    position: 'absolute' as const,
    opacity: 0,
    width: '100%',
    height: '100%',
    cursor: 'pointer',
  },
  uploadLabel: {
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    justifyContent: 'center',
    padding: '32px',
    backgroundColor: '#fff',
    border: '2px dashed #d9d9d9',
    borderRadius: '12px',
    cursor: 'pointer',
    transition: 'border-color 0.3s ease',
  },
  uploadIcon: {
    fontSize: '48px',
    marginBottom: '16px',
  },
  uploadText: {
    fontSize: '16px',
    color: '#333',
    marginBottom: '8px',
    textAlign: 'center' as const,
  },
  uploadSubtext: {
    fontSize: '14px',
    color: '#666',
    textAlign: 'center' as const,
  },
  fileInfo: {
    display: 'flex',
    justifyContent: 'space-between',
    alignItems: 'center',
    padding: '12px',
    backgroundColor: '#f0f0f0',
    borderRadius: '8px',
    marginBottom: '16px',
  },
  fileName: {
    fontSize: '14px',
    color: '#333',
    fontWeight: 'bold',
  },
  fileSize: {
    fontSize: '12px',
    color: '#666',
  },
  progressContainer: {
    marginBottom: '16px',
  },
  progressBar: {
    width: '100%',
    height: '8px',
    backgroundColor: '#f0f0f0',
    borderRadius: '4px',
    overflow: 'hidden',
    marginBottom: '8px',
  },
  progressFill: {
    height: '100%',
    backgroundColor: '#1890ff',
    transition: 'width 0.3s ease',
  },
  progressText: {
    fontSize: '12px',
    color: '#666',
    textAlign: 'center' as const,
  },
  uploadButton: {
    width: '100%',
    padding: '12px',
    border: 'none',
    borderRadius: '8px',
    fontSize: '16px',
    fontWeight: 'bold',
    color: '#fff',
    transition: 'background-color 0.3s ease',
  },
  languageSection: {
    marginBottom: '24px',
  },
  languageOptions: {
    display: 'flex',
    alignItems: 'center',
    gap: '12px',
    padding: '16px',
    backgroundColor: '#fff',
    borderRadius: '12px',
    boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
  },
  languageSelect: {
    flex: 1,
    padding: '8px 12px',
    border: '1px solid #d9d9d9',
    borderRadius: '6px',
    fontSize: '14px',
  },
  arrow: {
    fontSize: '16px',
    color: '#666',
  },
  documentsSection: {
    marginBottom: '24px',
  },
  documentsList: {
    display: 'flex',
    flexDirection: 'column' as const,
    gap: '12px',
  },
  documentItem: {
    display: 'flex',
    alignItems: 'center',
    padding: '16px',
    backgroundColor: '#fff',
    borderRadius: '12px',
    boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
  },
  documentIcon: {
    fontSize: '24px',
    marginRight: '16px',
  },
  documentInfo: {
    flex: 1,
  },
  documentName: {
    fontSize: '16px',
    fontWeight: 'bold',
    color: '#333',
    marginBottom: '4px',
  },
  documentMeta: {
    display: 'flex',
    gap: '12px',
    marginBottom: '4px',
  },
  documentLanguages: {
    fontSize: '12px',
    color: '#666',
  },
  documentSize: {
    fontSize: '12px',
    color: '#666',
  },
  documentDate: {
    fontSize: '12px',
    color: '#999',
  },
  documentStatus: {
    padding: '4px 8px',
    borderRadius: '4px',
    fontSize: '12px',
    fontWeight: 'bold',
  },
};

export default DocumentScreen; 