import React, { useState, useEffect } from 'react';
import {
  View,
  Text,
  StyleSheet,
  ScrollView,
  TouchableOpacity,
  Alert,
  SafeAreaView,
} from 'react-native';
import { mockUser, mockContract, mockCallSessions, mockUsageStats } from '@/utils/mockData';
import { User, Contract, CallSession } from '@/types';

const HomeScreen: React.FC = () => {
  const [user, setUser] = useState<User | null>(null);
  const [contract, setContract] = useState<Contract | null>(null);
  const [recentCalls, setRecentCalls] = useState<CallSession[]>([]);
  const [stats, setStats] = useState(mockUsageStats);

  useEffect(() => {
    // 模拟数据加载
    loadData();
  }, []);

  const loadData = async () => {
    // 在实际应用中，这里会调用API
    // const userResponse = await apiService.getUserProfile();
    // const contractResponse = await apiService.getUserContract();
    // const callsResponse = await apiService.getCallHistory(1, 5);
    
    // 使用模拟数据
    setUser(mockUser);
    setContract(mockContract);
    setRecentCalls(mockCallSessions.slice(0, 3));
  };

  const handleStartCall = (mode: 'ai' | 'human' | 'video' | 'sign') => {
    Alert.alert(
      '开始通话',
      `您选择了${mode === 'ai' ? 'AI翻译' : mode === 'human' ? '人工翻译' : mode === 'video' ? '视频翻译' : '手语翻译'}模式`,
      [
        { text: '取消', style: 'cancel' },
        { text: '确认', onPress: () => console.log(`Starting ${mode} call`) },
      ]
    );
  };

  const handleUploadDocument = () => {
    Alert.alert('文档翻译', '跳转到文档上传页面');
  };

  const formatDuration = (seconds: number): string => {
    const minutes = Math.floor(seconds / 60);
    const remainingSeconds = seconds % 60;
    return `${minutes}分${remainingSeconds}秒`;
  };

  const getStatusText = (status: string): string => {
    const statusMap: { [key: string]: string } = {
      completed: '已完成',
      cancelled: '已取消',
      pending: '等待中',
      active: '进行中',
    };
    return statusMap[status] || status;
  };

  const getStatusColor = (status: string): string => {
    const colorMap: { [key: string]: string } = {
      completed: '#4CAF50',
      cancelled: '#F44336',
      pending: '#FF9800',
      active: '#2196F3',
    };
    return colorMap[status] || '#666';
  };

  return (
    <SafeAreaView style={styles.container}>
      <ScrollView style={styles.scrollView} showsVerticalScrollIndicator={false}>
        {/* 用户信息卡片 */}
        <View style={styles.userCard}>
          <Text style={styles.welcomeText}>欢迎回来！</Text>
          <Text style={styles.userEmail}>{user?.email}</Text>
          <View style={styles.balanceContainer}>
            <Text style={styles.balanceLabel}>剩余分钟数</Text>
            <Text style={styles.balanceValue}>{contract?.creditBalance || 0}</Text>
          </View>
        </View>

        {/* 快速操作 */}
        <View style={styles.section}>
          <Text style={styles.sectionTitle}>快速开始</Text>
          <View style={styles.quickActions}>
            <TouchableOpacity
              style={[styles.actionButton, { backgroundColor: '#4CAF50' }]}
              onPress={() => handleStartCall('ai')}
            >
              <Text style={styles.actionButtonText}>🤖</Text>
              <Text style={styles.actionButtonLabel}>AI翻译</Text>
            </TouchableOpacity>

            <TouchableOpacity
              style={[styles.actionButton, { backgroundColor: '#2196F3' }]}
              onPress={() => handleStartCall('human')}
            >
              <Text style={styles.actionButtonText}>👥</Text>
              <Text style={styles.actionButtonLabel}>人工翻译</Text>
            </TouchableOpacity>

            <TouchableOpacity
              style={[styles.actionButton, { backgroundColor: '#FF9800' }]}
              onPress={() => handleStartCall('video')}
            >
              <Text style={styles.actionButtonText}>📹</Text>
              <Text style={styles.actionButtonLabel}>视频翻译</Text>
            </TouchableOpacity>

            <TouchableOpacity
              style={[styles.actionButton, { backgroundColor: '#9C27B0' }]}
              onPress={() => handleStartCall('sign')}
            >
              <Text style={styles.actionButtonText}>🤟</Text>
              <Text style={styles.actionButtonLabel}>手语翻译</Text>
            </TouchableOpacity>
          </View>
        </View>

        {/* 文档翻译 */}
        <View style={styles.section}>
          <TouchableOpacity style={styles.documentButton} onPress={handleUploadDocument}>
            <Text style={styles.documentButtonIcon}>📄</Text>
            <View style={styles.documentButtonContent}>
              <Text style={styles.documentButtonTitle}>文档翻译</Text>
              <Text style={styles.documentButtonSubtitle}>上传文档进行专业翻译</Text>
            </View>
            <Text style={styles.documentButtonArrow}>›</Text>
          </TouchableOpacity>
        </View>

        {/* 使用统计 */}
        <View style={styles.section}>
          <Text style={styles.sectionTitle}>本月统计</Text>
          <View style={styles.statsContainer}>
            <View style={styles.statItem}>
              <Text style={styles.statValue}>{stats.monthlyBreakdown[0]?.calls || 0}</Text>
              <Text style={styles.statLabel}>通话次数</Text>
            </View>
            <View style={styles.statItem}>
              <Text style={styles.statValue}>{stats.monthlyBreakdown[0]?.minutes || 0}</Text>
              <Text style={styles.statLabel}>通话分钟</Text>
            </View>
            <View style={styles.statItem}>
              <Text style={styles.statValue}>${stats.monthlyBreakdown[0]?.cost || 0}</Text>
              <Text style={styles.statLabel}>总费用</Text>
            </View>
          </View>
        </View>

        {/* 最近通话 */}
        <View style={styles.section}>
          <Text style={styles.sectionTitle}>最近通话</Text>
          {recentCalls.map((call) => (
            <View key={call.id} style={styles.callItem}>
              <View style={styles.callInfo}>
                <Text style={styles.callLanguages}>
                  {call.sourceLanguage.toUpperCase()} → {call.targetLanguage.toUpperCase()}
                </Text>
                <Text style={styles.callDuration}>
                  {formatDuration(call.duration)}
                </Text>
                <Text style={styles.callDate}>
                  {new Date(call.createdAt).toLocaleDateString('zh-CN')}
                </Text>
              </View>
              <View style={styles.callStatus}>
                <Text style={[styles.statusText, { color: getStatusColor(call.status) }]}>
                  {getStatusText(call.status)}
                </Text>
                <Text style={styles.callCost}>${call.cost.toFixed(2)}</Text>
              </View>
            </View>
          ))}
          <TouchableOpacity style={styles.viewAllButton}>
            <Text style={styles.viewAllText}>查看全部通话记录</Text>
          </TouchableOpacity>
        </View>
      </ScrollView>
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#f5f5f5',
  },
  scrollView: {
    flex: 1,
    padding: 16,
  },
  userCard: {
    backgroundColor: '#fff',
    borderRadius: 12,
    padding: 20,
    marginBottom: 20,
    shadowColor: '#000',
    shadowOffset: { width: 0, height: 2 },
    shadowOpacity: 0.1,
    shadowRadius: 4,
    elevation: 3,
  },
  welcomeText: {
    fontSize: 24,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 4,
  },
  userEmail: {
    fontSize: 16,
    color: '#666',
    marginBottom: 16,
  },
  balanceContainer: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    backgroundColor: '#f8f9fa',
    padding: 12,
    borderRadius: 8,
  },
  balanceLabel: {
    fontSize: 16,
    color: '#666',
  },
  balanceValue: {
    fontSize: 20,
    fontWeight: 'bold',
    color: '#4CAF50',
  },
  section: {
    marginBottom: 24,
  },
  sectionTitle: {
    fontSize: 18,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 12,
  },
  quickActions: {
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
  actionButton: {
    flex: 1,
    alignItems: 'center',
    padding: 16,
    borderRadius: 12,
    marginHorizontal: 4,
  },
  actionButtonText: {
    fontSize: 24,
    marginBottom: 8,
  },
  actionButtonLabel: {
    color: '#fff',
    fontSize: 12,
    fontWeight: 'bold',
    textAlign: 'center',
  },
  documentButton: {
    backgroundColor: '#fff',
    borderRadius: 12,
    padding: 16,
    flexDirection: 'row',
    alignItems: 'center',
    shadowColor: '#000',
    shadowOffset: { width: 0, height: 2 },
    shadowOpacity: 0.1,
    shadowRadius: 4,
    elevation: 3,
  },
  documentButtonIcon: {
    fontSize: 32,
    marginRight: 16,
  },
  documentButtonContent: {
    flex: 1,
  },
  documentButtonTitle: {
    fontSize: 16,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 4,
  },
  documentButtonSubtitle: {
    fontSize: 14,
    color: '#666',
  },
  documentButtonArrow: {
    fontSize: 24,
    color: '#ccc',
  },
  statsContainer: {
    flexDirection: 'row',
    backgroundColor: '#fff',
    borderRadius: 12,
    padding: 16,
    shadowColor: '#000',
    shadowOffset: { width: 0, height: 2 },
    shadowOpacity: 0.1,
    shadowRadius: 4,
    elevation: 3,
  },
  statItem: {
    flex: 1,
    alignItems: 'center',
  },
  statValue: {
    fontSize: 20,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 4,
  },
  statLabel: {
    fontSize: 12,
    color: '#666',
    textAlign: 'center',
  },
  callItem: {
    backgroundColor: '#fff',
    borderRadius: 8,
    padding: 16,
    marginBottom: 8,
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    shadowColor: '#000',
    shadowOffset: { width: 0, height: 1 },
    shadowOpacity: 0.05,
    shadowRadius: 2,
    elevation: 1,
  },
  callInfo: {
    flex: 1,
  },
  callLanguages: {
    fontSize: 16,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 4,
  },
  callDuration: {
    fontSize: 14,
    color: '#666',
    marginBottom: 2,
  },
  callDate: {
    fontSize: 12,
    color: '#999',
  },
  callStatus: {
    alignItems: 'flex-end',
  },
  statusText: {
    fontSize: 12,
    fontWeight: 'bold',
    marginBottom: 4,
  },
  callCost: {
    fontSize: 14,
    fontWeight: 'bold',
    color: '#333',
  },
  viewAllButton: {
    backgroundColor: '#fff',
    borderRadius: 8,
    padding: 12,
    alignItems: 'center',
    marginTop: 8,
    borderWidth: 1,
    borderColor: '#e0e0e0',
  },
  viewAllText: {
    fontSize: 14,
    color: '#2196F3',
    fontWeight: 'bold',
  },
});

export default HomeScreen; 