import React, { useState, useEffect } from 'react';
import {
  View,
  Text,
  StyleSheet,
  TouchableOpacity,
  ScrollView,
  SafeAreaView,
  Switch,
  Alert,
  Modal,
  TextInput,
} from 'react-native';
import { mockUser, mockLanguages } from '@/utils/mockData';
import { User, Language } from '@/types';

interface SettingsScreenProps {
  navigation?: any;
}

const SettingsScreen: React.FC<SettingsScreenProps> = ({ navigation }) => {
  const [user, setUser] = useState<User | null>(null);
  const [settings, setSettings] = useState({
    notifications: {
      push: true,
      email: true,
      sms: false,
      appointment: true,
      document: true,
    },
    preferences: {
      defaultSourceLanguage: 'zh',
      defaultTargetLanguage: 'en',
      autoJoinCalls: false,
      highQualityAudio: true,
      darkMode: false,
    },
    privacy: {
      shareUsageData: false,
      recordCalls: true,
      storeDocuments: true,
    },
  });
  const [editProfileModal, setEditProfileModal] = useState(false);
  const [editedProfile, setEditedProfile] = useState({
    name: '',
    email: '',
    phone: '',
  });

  useEffect(() => {
    loadUserData();
  }, []);

  const loadUserData = async () => {
    try {
      // 模拟API调用
      setTimeout(() => {
        setUser(mockUser);
        setEditedProfile({
          name: mockUser.name || '',
          email: mockUser.email,
          phone: mockUser.phone || '',
        });
      }, 500);
    } catch (error) {
      console.error('Failed to load user data:', error);
    }
  };

  const getLanguageInfo = (code: string): Language | undefined => {
    return mockLanguages.find(lang => lang.code === code);
  };

  const handleUpdateProfile = async () => {
    try {
      // 模拟API调用
      const updatedUser = {
        ...user!,
        name: editedProfile.name,
        email: editedProfile.email,
        phone: editedProfile.phone,
      };
      
      setUser(updatedUser);
      setEditProfileModal(false);
      Alert.alert('成功', '个人信息已更新');
    } catch (error) {
      console.error('Failed to update profile:', error);
      Alert.alert('错误', '更新失败，请重试');
    }
  };

  const handleLogout = () => {
    Alert.alert(
      '退出登录',
      '确定要退出登录吗？',
      [
        { text: '取消', style: 'cancel' },
        {
          text: '确定',
          style: 'destructive',
          onPress: () => {
            // 在实际应用中清除认证状态
            navigation?.navigate('Auth');
          }
        },
      ]
    );
  };

  const handleDeleteAccount = () => {
    Alert.alert(
      '删除账户',
      '此操作不可逆，确定要删除您的账户吗？',
      [
        { text: '取消', style: 'cancel' },
        {
          text: '删除',
          style: 'destructive',
          onPress: () => {
            Alert.alert('确认删除', '请再次确认删除账户', [
              { text: '取消', style: 'cancel' },
              {
                text: '确定删除',
                style: 'destructive',
                onPress: () => {
                  // 在实际应用中调用删除API
                  Alert.alert('账户已删除', '您的账户已被删除');
                }
              },
            ]);
          }
        },
      ]
    );
  };

  const updateNotificationSetting = (key: string, value: boolean) => {
    setSettings(prev => ({
      ...prev,
      notifications: {
        ...prev.notifications,
        [key]: value,
      },
    }));
  };

  const updatePreferenceSetting = (key: string, value: any) => {
    setSettings(prev => ({
      ...prev,
      preferences: {
        ...prev.preferences,
        [key]: value,
      },
    }));
  };

  const updatePrivacySetting = (key: string, value: boolean) => {
    setSettings(prev => ({
      ...prev,
      privacy: {
        ...prev.privacy,
        [key]: value,
      },
    }));
  };

  const renderSettingItem = (
    title: string,
    subtitle: string,
    value: boolean,
    onToggle: (value: boolean) => void
  ) => (
    <View style={styles.settingItem}>
      <View style={styles.settingInfo}>
        <Text style={styles.settingTitle}>{title}</Text>
        <Text style={styles.settingSubtitle}>{subtitle}</Text>
      </View>
      <Switch
        value={value}
        onValueChange={onToggle}
        trackColor={{ false: '#e0e0e0', true: '#2196F3' }}
        thumbColor={value ? '#fff' : '#f4f3f4'}
      />
    </View>
  );

  const renderLanguageSelector = (
    title: string,
    currentLanguage: string,
    onSelect: (language: string) => void
  ) => {
    const language = getLanguageInfo(currentLanguage);
    
    return (
      <TouchableOpacity style={styles.settingItem}>
        <View style={styles.settingInfo}>
          <Text style={styles.settingTitle}>{title}</Text>
          <Text style={styles.settingSubtitle}>
            {language?.flag} {language?.nativeName}
          </Text>
        </View>
        <Text style={styles.chevron}>›</Text>
      </TouchableOpacity>
    );
  };

  const renderProfileModal = () => (
    <Modal
      visible={editProfileModal}
      transparent
      animationType="slide"
      onRequestClose={() => setEditProfileModal(false)}
    >
      <View style={styles.modalOverlay}>
        <View style={styles.modalContent}>
          <Text style={styles.modalTitle}>编辑个人信息</Text>

          <View style={styles.formGroup}>
            <Text style={styles.formLabel}>姓名</Text>
            <TextInput
              style={styles.textInput}
              value={editedProfile.name}
              onChangeText={(text) => setEditedProfile(prev => ({ ...prev, name: text }))}
              placeholder="输入姓名"
            />
          </View>

          <View style={styles.formGroup}>
            <Text style={styles.formLabel}>邮箱</Text>
            <TextInput
              style={styles.textInput}
              value={editedProfile.email}
              onChangeText={(text) => setEditedProfile(prev => ({ ...prev, email: text }))}
              placeholder="输入邮箱"
              keyboardType="email-address"
            />
          </View>

          <View style={styles.formGroup}>
            <Text style={styles.formLabel}>手机号</Text>
            <TextInput
              style={styles.textInput}
              value={editedProfile.phone}
              onChangeText={(text) => setEditedProfile(prev => ({ ...prev, phone: text }))}
              placeholder="输入手机号"
              keyboardType="phone-pad"
            />
          </View>

          <View style={styles.modalActions}>
            <TouchableOpacity
              style={[styles.modalButton, styles.cancelButton]}
              onPress={() => setEditProfileModal(false)}
            >
              <Text style={styles.cancelButtonText}>取消</Text>
            </TouchableOpacity>
            <TouchableOpacity
              style={[styles.modalButton, styles.saveButton]}
              onPress={handleUpdateProfile}
            >
              <Text style={styles.saveButtonText}>保存</Text>
            </TouchableOpacity>
          </View>
        </View>
      </View>
    </Modal>
  );

  if (!user) {
    return (
      <SafeAreaView style={styles.container}>
        <View style={styles.loadingContainer}>
          <Text style={styles.loadingText}>加载中...</Text>
        </View>
      </SafeAreaView>
    );
  }

  return (
    <SafeAreaView style={styles.container}>
      <View style={styles.header}>
        <Text style={styles.headerTitle}>设置</Text>
      </View>

      <ScrollView style={styles.content} showsVerticalScrollIndicator={false}>
        {/* 用户信息 */}
        <View style={styles.section}>
          <Text style={styles.sectionTitle}>个人信息</Text>
          <View style={styles.profileCard}>
            <View style={styles.avatar}>
              <Text style={styles.avatarText}>
                {user.name ? user.name.charAt(0).toUpperCase() : user.email.charAt(0).toUpperCase()}
              </Text>
            </View>
            <View style={styles.profileInfo}>
              <Text style={styles.profileName}>{user.name || '未设置姓名'}</Text>
              <Text style={styles.profileEmail}>{user.email}</Text>
              {user.phone && <Text style={styles.profilePhone}>{user.phone}</Text>}
            </View>
            <TouchableOpacity 
              style={styles.editButton}
              onPress={() => setEditProfileModal(true)}
            >
              <Text style={styles.editButtonText}>编辑</Text>
            </TouchableOpacity>
          </View>
        </View>

        {/* 通知设置 */}
        <View style={styles.section}>
          <Text style={styles.sectionTitle}>通知设置</Text>
          {renderSettingItem(
            '推送通知',
            '接收应用推送通知',
            settings.notifications.push,
            (value) => updateNotificationSetting('push', value)
          )}
          {renderSettingItem(
            '邮件通知',
            '接收邮件通知',
            settings.notifications.email,
            (value) => updateNotificationSetting('email', value)
          )}
          {renderSettingItem(
            '短信通知',
            '接收短信通知',
            settings.notifications.sms,
            (value) => updateNotificationSetting('sms', value)
          )}
          {renderSettingItem(
            '预约提醒',
            '预约开始前提醒',
            settings.notifications.appointment,
            (value) => updateNotificationSetting('appointment', value)
          )}
          {renderSettingItem(
            '文档通知',
            '文档翻译完成通知',
            settings.notifications.document,
            (value) => updateNotificationSetting('document', value)
          )}
        </View>

        {/* 偏好设置 */}
        <View style={styles.section}>
          <Text style={styles.sectionTitle}>偏好设置</Text>
          {renderLanguageSelector(
            '默认源语言',
            settings.preferences.defaultSourceLanguage,
            (language) => updatePreferenceSetting('defaultSourceLanguage', language)
          )}
          {renderLanguageSelector(
            '默认目标语言',
            settings.preferences.defaultTargetLanguage,
            (language) => updatePreferenceSetting('defaultTargetLanguage', language)
          )}
          {renderSettingItem(
            '自动加入通话',
            '预约时间到达时自动加入',
            settings.preferences.autoJoinCalls,
            (value) => updatePreferenceSetting('autoJoinCalls', value)
          )}
          {renderSettingItem(
            '高质量音频',
            '使用高质量音频传输',
            settings.preferences.highQualityAudio,
            (value) => updatePreferenceSetting('highQualityAudio', value)
          )}
          {renderSettingItem(
            '深色模式',
            '使用深色主题',
            settings.preferences.darkMode,
            (value) => updatePreferenceSetting('darkMode', value)
          )}
        </View>

        {/* 隐私设置 */}
        <View style={styles.section}>
          <Text style={styles.sectionTitle}>隐私设置</Text>
          {renderSettingItem(
            '分享使用数据',
            '帮助改进应用体验',
            settings.privacy.shareUsageData,
            (value) => updatePrivacySetting('shareUsageData', value)
          )}
          {renderSettingItem(
            '录制通话',
            '保存通话记录用于质量改进',
            settings.privacy.recordCalls,
            (value) => updatePrivacySetting('recordCalls', value)
          )}
          {renderSettingItem(
            '存储文档',
            '在云端保存翻译文档',
            settings.privacy.storeDocuments,
            (value) => updatePrivacySetting('storeDocuments', value)
          )}
        </View>

        {/* 其他选项 */}
        <View style={styles.section}>
          <Text style={styles.sectionTitle}>其他</Text>
          <TouchableOpacity style={styles.actionItem}>
            <Text style={styles.actionTitle}>帮助与支持</Text>
            <Text style={styles.chevron}>›</Text>
          </TouchableOpacity>
          <TouchableOpacity style={styles.actionItem}>
            <Text style={styles.actionTitle}>关于我们</Text>
            <Text style={styles.chevron}>›</Text>
          </TouchableOpacity>
          <TouchableOpacity style={styles.actionItem}>
            <Text style={styles.actionTitle}>隐私政策</Text>
            <Text style={styles.chevron}>›</Text>
          </TouchableOpacity>
          <TouchableOpacity style={styles.actionItem}>
            <Text style={styles.actionTitle}>服务条款</Text>
            <Text style={styles.chevron}>›</Text>
          </TouchableOpacity>
        </View>

        {/* 危险操作 */}
        <View style={styles.section}>
          <TouchableOpacity style={styles.logoutButton} onPress={handleLogout}>
            <Text style={styles.logoutButtonText}>退出登录</Text>
          </TouchableOpacity>
          <TouchableOpacity style={styles.deleteButton} onPress={handleDeleteAccount}>
            <Text style={styles.deleteButtonText}>删除账户</Text>
          </TouchableOpacity>
        </View>
      </ScrollView>

      {renderProfileModal()}
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#f5f5f5',
  },
  header: {
    padding: 16,
    backgroundColor: '#fff',
    borderBottomWidth: 1,
    borderBottomColor: '#e0e0e0',
  },
  headerTitle: {
    fontSize: 20,
    fontWeight: 'bold',
    color: '#333',
  },
  content: {
    flex: 1,
  },
  loadingContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
  },
  loadingText: {
    fontSize: 16,
    color: '#666',
  },
  section: {
    marginTop: 16,
    backgroundColor: '#fff',
    paddingVertical: 8,
  },
  sectionTitle: {
    fontSize: 14,
    fontWeight: 'bold',
    color: '#666',
    paddingHorizontal: 16,
    paddingVertical: 8,
    backgroundColor: '#f8f8f8',
  },
  profileCard: {
    flexDirection: 'row',
    alignItems: 'center',
    padding: 16,
  },
  avatar: {
    width: 60,
    height: 60,
    borderRadius: 30,
    backgroundColor: '#2196F3',
    justifyContent: 'center',
    alignItems: 'center',
    marginRight: 16,
  },
  avatarText: {
    fontSize: 24,
    fontWeight: 'bold',
    color: '#fff',
  },
  profileInfo: {
    flex: 1,
  },
  profileName: {
    fontSize: 18,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 4,
  },
  profileEmail: {
    fontSize: 14,
    color: '#666',
    marginBottom: 2,
  },
  profilePhone: {
    fontSize: 14,
    color: '#666',
  },
  editButton: {
    backgroundColor: '#2196F3',
    paddingHorizontal: 16,
    paddingVertical: 8,
    borderRadius: 16,
  },
  editButtonText: {
    color: '#fff',
    fontSize: 12,
    fontWeight: 'bold',
  },
  settingItem: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    paddingHorizontal: 16,
    paddingVertical: 12,
    borderBottomWidth: 1,
    borderBottomColor: '#f0f0f0',
  },
  settingInfo: {
    flex: 1,
  },
  settingTitle: {
    fontSize: 16,
    color: '#333',
    marginBottom: 2,
  },
  settingSubtitle: {
    fontSize: 12,
    color: '#666',
  },
  chevron: {
    fontSize: 20,
    color: '#ccc',
  },
  actionItem: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    paddingHorizontal: 16,
    paddingVertical: 16,
    borderBottomWidth: 1,
    borderBottomColor: '#f0f0f0',
  },
  actionTitle: {
    fontSize: 16,
    color: '#333',
  },
  logoutButton: {
    backgroundColor: '#FF9800',
    marginHorizontal: 16,
    marginVertical: 8,
    paddingVertical: 12,
    borderRadius: 8,
    alignItems: 'center',
  },
  logoutButtonText: {
    color: '#fff',
    fontSize: 16,
    fontWeight: 'bold',
  },
  deleteButton: {
    backgroundColor: '#F44336',
    marginHorizontal: 16,
    marginBottom: 16,
    paddingVertical: 12,
    borderRadius: 8,
    alignItems: 'center',
  },
  deleteButtonText: {
    color: '#fff',
    fontSize: 16,
    fontWeight: 'bold',
  },
  modalOverlay: {
    flex: 1,
    backgroundColor: 'rgba(0, 0, 0, 0.5)',
    justifyContent: 'center',
    alignItems: 'center',
  },
  modalContent: {
    backgroundColor: '#fff',
    borderRadius: 16,
    padding: 24,
    width: '90%',
    maxWidth: 400,
  },
  modalTitle: {
    fontSize: 20,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 24,
    textAlign: 'center',
  },
  formGroup: {
    marginBottom: 16,
  },
  formLabel: {
    fontSize: 14,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 8,
  },
  textInput: {
    borderWidth: 1,
    borderColor: '#e0e0e0',
    borderRadius: 8,
    padding: 12,
    fontSize: 14,
    color: '#333',
  },
  modalActions: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    marginTop: 24,
  },
  modalButton: {
    flex: 1,
    paddingVertical: 12,
    borderRadius: 24,
    alignItems: 'center',
    marginHorizontal: 8,
  },
  cancelButton: {
    backgroundColor: '#f0f0f0',
  },
  cancelButtonText: {
    color: '#666',
    fontSize: 14,
    fontWeight: 'bold',
  },
  saveButton: {
    backgroundColor: '#2196F3',
  },
  saveButtonText: {
    color: '#fff',
    fontSize: 14,
    fontWeight: 'bold',
  },
});

export default SettingsScreen; 