import { 
  User, 
  TranslationCall, 
  DocumentTranslation, 
  Appointment, 
  Translator, 
  Payment, 
  DashboardStats, 
  ChartData, 
  SystemSettings, 
  Notification,
  SystemLog,
  ApiResponse, 
  QueryParams 
} from '@/types';
import { mockData } from './mockData';

// API基础配置
const API_BASE_URL = (import.meta as any).env?.VITE_API_BASE_URL || 'http://localhost:3001/api';
const USE_MOCK_DATA = (import.meta as any).env?.VITE_USE_MOCK_DATA !== 'false';

// HTTP客户端配置
class ApiClient {
  private baseUrl: string;
  private token: string | null = null;

  constructor(baseUrl: string) {
    this.baseUrl = baseUrl;
    this.token = localStorage.getItem('token');
  }

  setToken(token: string) {
    this.token = token;
    localStorage.setItem('token', token);
  }

  removeToken() {
    this.token = null;
    localStorage.removeItem('token');
  }

  private async request<T>(
    endpoint: string, 
    options: RequestInit = {}
  ): Promise<ApiResponse<T>> {
    const url = `${this.baseUrl}${endpoint}`;
    const headers: Record<string, string> = {
      'Content-Type': 'application/json',
      ...(options.headers as Record<string, string>),
    };

    if (this.token) {
      headers['Authorization'] = `Bearer ${this.token}`;
    }

    try {
      const response = await fetch(url, {
        ...options,
        headers,
      });

      if (!response.ok) {
        throw new Error(`HTTP error! status: ${response.status}`);
      }

      const data = await response.json();
      return data;
    } catch (error) {
      console.error('API request failed:', error);
      throw error;
    }
  }

  async get<T>(endpoint: string, params?: Record<string, any>): Promise<ApiResponse<T>> {
    const url = params ? `${endpoint}?${new URLSearchParams(params)}` : endpoint;
    return this.request<T>(url);
  }

  async post<T>(endpoint: string, data?: any): Promise<ApiResponse<T>> {
    return this.request<T>(endpoint, {
      method: 'POST',
      body: data ? JSON.stringify(data) : undefined,
    });
  }

  async put<T>(endpoint: string, data?: any): Promise<ApiResponse<T>> {
    return this.request<T>(endpoint, {
      method: 'PUT',
      body: data ? JSON.stringify(data) : undefined,
    });
  }

  async delete<T>(endpoint: string): Promise<ApiResponse<T>> {
    return this.request<T>(endpoint, {
      method: 'DELETE',
    });
  }
}

const apiClient = new ApiClient(API_BASE_URL);

// Mock数据模拟延迟
const mockDelay = (ms: number = 1000) => new Promise(resolve => setTimeout(resolve, ms));

// 分页和筛选辅助函数
const applyFilters = <T extends Record<string, any>>(
  data: T[], 
  params: QueryParams
): { data: T[], total: number } => {
  let filtered = [...data];

  // 搜索过滤
  if (params.search) {
    const searchLower = params.search.toLowerCase();
    filtered = filtered.filter(item => 
      Object.values(item).some(value => 
        value?.toString().toLowerCase().includes(searchLower)
      )
    );
  }

  // 状态过滤
  if (params.status) {
    filtered = filtered.filter(item => item.status === params.status);
  }

  // 日期范围过滤
  if (params.startDate || params.endDate) {
    filtered = filtered.filter(item => {
      const itemDate = new Date(item.createdAt || item.startTime);
      const start = params.startDate ? new Date(params.startDate) : null;
      const end = params.endDate ? new Date(params.endDate) : null;
      
      if (start && itemDate < start) return false;
      if (end && itemDate > end) return false;
      return true;
    });
  }

  const total = filtered.length;

  // 排序
  if (params.sortBy) {
    filtered.sort((a, b) => {
      const aValue = a[params.sortBy!];
      const bValue = b[params.sortBy!];
      const order = params.sortOrder === 'desc' ? -1 : 1;
      
      if (aValue < bValue) return -1 * order;
      if (aValue > bValue) return 1 * order;
      return 0;
    });
  }

  // 分页
  const page = params.page || 1;
  const limit = params.limit || 10;
  const offset = (page - 1) * limit;
  const paginatedData = filtered.slice(offset, offset + limit);

  return { data: paginatedData, total };
};

// 用户管理API
export const userApi = {
  async getUsers(params: QueryParams = {}): Promise<ApiResponse<User[]>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const { data, total } = applyFilters(mockData.users, params);
      return {
        success: true,
        data,
        pagination: {
          page: params.page || 1,
          limit: params.limit || 10,
          total,
          totalPages: Math.ceil(total / (params.limit || 10))
        }
      };
    }
    return apiClient.get<User[]>('/users', params);
  },

  async getUser(id: string): Promise<ApiResponse<User>> {
    if (USE_MOCK_DATA) {
      await mockDelay(500);
      const user = mockData.users.find(u => u.id === id);
      if (!user) {
        throw new Error('用户不存在');
      }
      return { success: true, data: user };
    }
    return apiClient.get<User>(`/users/${id}`);
  },

  async createUser(userData: Partial<User>): Promise<ApiResponse<User>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const newUser: User = {
        id: Date.now().toString(),
        email: userData.email!,
        name: userData.name!,
        phone: userData.phone || '',
        avatar: userData.avatar || `https://api.dicebear.com/7.x/avataaars/svg?seed=${userData.name}`,
        role: userData.role || 'user',
        status: userData.status || 'active',
        createdAt: new Date().toISOString(),
        updatedAt: new Date().toISOString(),
        lastLoginAt: new Date().toISOString(),
        preferences: userData.preferences || {
          language: 'zh-CN',
          timezone: 'Asia/Shanghai',
          notifications: { email: true, sms: false, push: true },
          theme: 'light'
        }
      };
      mockData.users.push(newUser);
      return { success: true, data: newUser };
    }
    return apiClient.post<User>('/users', userData);
  },

  async updateUser(id: string, userData: Partial<User>): Promise<ApiResponse<User>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const index = mockData.users.findIndex(u => u.id === id);
      if (index === -1) {
        throw new Error('用户不存在');
      }
      const updatedUser = { 
        ...mockData.users[index], 
        ...userData, 
        updatedAt: new Date().toISOString() 
      };
      mockData.users[index] = updatedUser;
      return { success: true, data: updatedUser };
    }
    return apiClient.put<User>(`/users/${id}`, userData);
  },

  async deleteUser(id: string): Promise<ApiResponse<void>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const index = mockData.users.findIndex(u => u.id === id);
      if (index === -1) {
        throw new Error('用户不存在');
      }
      mockData.users.splice(index, 1);
      return { success: true, data: undefined };
    }
    return apiClient.delete<void>(`/users/${id}`);
  }
};

// 翻译通话API
export const callApi = {
  async getCalls(params: QueryParams = {}): Promise<ApiResponse<TranslationCall[]>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const { data, total } = applyFilters(mockData.translationCalls, params);
      return {
        success: true,
        data,
        pagination: {
          page: params.page || 1,
          limit: params.limit || 10,
          total,
          totalPages: Math.ceil(total / (params.limit || 10))
        }
      };
    }
    return apiClient.get<TranslationCall[]>('/calls', params);
  },

  async getCall(id: string): Promise<ApiResponse<TranslationCall>> {
    if (USE_MOCK_DATA) {
      await mockDelay(500);
      const call = mockData.translationCalls.find(c => c.id === id);
      if (!call) {
        throw new Error('通话记录不存在');
      }
      return { success: true, data: call };
    }
    return apiClient.get<TranslationCall>(`/calls/${id}`);
  },

  async updateCall(id: string, callData: Partial<TranslationCall>): Promise<ApiResponse<TranslationCall>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const index = mockData.translationCalls.findIndex(c => c.id === id);
      if (index === -1) {
        throw new Error('通话记录不存在');
      }
      const updatedCall = { 
        ...mockData.translationCalls[index], 
        ...callData, 
        updatedAt: new Date().toISOString() 
      };
      mockData.translationCalls[index] = updatedCall;
      return { success: true, data: updatedCall };
    }
    return apiClient.put<TranslationCall>(`/calls/${id}`, callData);
  },

  async deleteCall(id: string): Promise<ApiResponse<void>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const index = mockData.translationCalls.findIndex(c => c.id === id);
      if (index === -1) {
        throw new Error('通话记录不存在');
      }
      mockData.translationCalls.splice(index, 1);
      return { success: true, data: undefined };
    }
    return apiClient.delete<void>(`/calls/${id}`);
  },

  async batchDeleteCalls(ids: string[]): Promise<ApiResponse<void>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      ids.forEach(id => {
        const index = mockData.translationCalls.findIndex(c => c.id === id);
        if (index !== -1) {
          mockData.translationCalls.splice(index, 1);
        }
      });
      return { success: true, data: undefined };
    }
    return apiClient.post<void>('/calls/batch-delete', { ids });
  },

  async getCallRecordingUrl(callId: string): Promise<string> {
    if (USE_MOCK_DATA) {
      await mockDelay(500);
      // 返回模拟的录音文件 URL
      return `https://example.com/recordings/${callId}.mp3`;
    }
    const response = await apiClient.get<{ url: string }>(`/calls/${callId}/recording`);
    return response.data?.url || '';
  }
};

// 文档翻译API
export const documentApi = {
  async getDocuments(params: QueryParams = {}): Promise<ApiResponse<DocumentTranslation[]>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const { data, total } = applyFilters(mockData.documentTranslations, params);
      return {
        success: true,
        data,
        pagination: {
          page: params.page || 1,
          limit: params.limit || 10,
          total,
          totalPages: Math.ceil(total / (params.limit || 10))
        }
      };
    }
    return apiClient.get<DocumentTranslation[]>('/documents', params);
  },

  async getDocument(id: string): Promise<ApiResponse<DocumentTranslation>> {
    if (USE_MOCK_DATA) {
      await mockDelay(500);
      const document = mockData.documentTranslations.find(d => d.id === id);
      if (!document) {
        throw new Error('文档不存在');
      }
      return { success: true, data: document };
    }
    return apiClient.get<DocumentTranslation>(`/documents/${id}`);
  },

  async updateDocument(id: string, docData: Partial<DocumentTranslation>): Promise<ApiResponse<DocumentTranslation>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const index = mockData.documentTranslations.findIndex(d => d.id === id);
      if (index === -1) {
        throw new Error('文档不存在');
      }
      const updatedDocument = { 
        ...mockData.documentTranslations[index], 
        ...docData, 
        updatedAt: new Date().toISOString() 
      };
      mockData.documentTranslations[index] = updatedDocument;
      return { success: true, data: updatedDocument };
    }
    return apiClient.put<DocumentTranslation>(`/documents/${id}`, docData);
  }
};

// 预约管理API
export const appointmentApi = {
  async getAppointments(params: QueryParams = {}): Promise<ApiResponse<Appointment[]>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const { data, total } = applyFilters(mockData.appointments, params);
      return {
        success: true,
        data,
        pagination: {
          page: params.page || 1,
          limit: params.limit || 10,
          total,
          totalPages: Math.ceil(total / (params.limit || 10))
        }
      };
    }
    return apiClient.get<Appointment[]>('/appointments', params);
  },

  async getAppointment(id: string): Promise<ApiResponse<Appointment>> {
    if (USE_MOCK_DATA) {
      await mockDelay(500);
      const appointment = mockData.appointments.find(a => a.id === id);
      if (!appointment) {
        throw new Error('预约不存在');
      }
      return { success: true, data: appointment };
    }
    return apiClient.get<Appointment>(`/appointments/${id}`);
  },

  async createAppointment(appointmentData: Partial<Appointment>): Promise<ApiResponse<Appointment>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const newAppointment: Appointment = {
        id: `apt_${Date.now()}`,
        userId: appointmentData.userId!,
        translatorId: appointmentData.translatorId,
        title: appointmentData.title!,
        description: appointmentData.description || '',
        type: appointmentData.type!,
        sourceLanguage: appointmentData.sourceLanguage!,
        targetLanguage: appointmentData.targetLanguage!,
        startTime: appointmentData.startTime!,
        endTime: appointmentData.endTime!,
        status: appointmentData.status || 'scheduled',
        cost: appointmentData.cost || 0,
        meetingUrl: appointmentData.meetingUrl,
        notes: appointmentData.notes || '',
        reminderSent: false,
        createdAt: new Date().toISOString(),
        updatedAt: new Date().toISOString()
      };
      mockData.appointments.push(newAppointment);
      return { success: true, data: newAppointment };
    }
    return apiClient.post<Appointment>('/appointments', appointmentData);
  },

  async updateAppointment(id: string, appointmentData: Partial<Appointment>): Promise<ApiResponse<Appointment>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const index = mockData.appointments.findIndex(a => a.id === id);
      if (index === -1) {
        throw new Error('预约不存在');
      }
      const updatedAppointment = { 
        ...mockData.appointments[index], 
        ...appointmentData, 
        updatedAt: new Date().toISOString() 
      };
      mockData.appointments[index] = updatedAppointment;
      return { success: true, data: updatedAppointment };
    }
    return apiClient.put<Appointment>(`/appointments/${id}`, appointmentData);
  },

  async deleteAppointment(id: string): Promise<ApiResponse<void>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const index = mockData.appointments.findIndex(a => a.id === id);
      if (index === -1) {
        throw new Error('预约不存在');
      }
      mockData.appointments.splice(index, 1);
      return { success: true, data: undefined };
    }
    return apiClient.delete<void>(`/appointments/${id}`);
  }
};

// 译员管理API
export const translatorApi = {
  async getTranslators(params: QueryParams = {}): Promise<ApiResponse<Translator[]>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const { data, total } = applyFilters(mockData.translators, params);
      return {
        success: true,
        data,
        pagination: {
          page: params.page || 1,
          limit: params.limit || 10,
          total,
          totalPages: Math.ceil(total / (params.limit || 10))
        }
      };
    }
    return apiClient.get<Translator[]>('/translators', params);
  },

  async getTranslator(id: string): Promise<ApiResponse<Translator>> {
    if (USE_MOCK_DATA) {
      await mockDelay(500);
      const translator = mockData.translators.find(t => t.id === id);
      if (!translator) {
        throw new Error('译员不存在');
      }
      return { success: true, data: translator };
    }
    return apiClient.get<Translator>(`/translators/${id}`);
  },

  async updateTranslator(id: string, translatorData: Partial<Translator>): Promise<ApiResponse<Translator>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const index = mockData.translators.findIndex(t => t.id === id);
      if (index === -1) {
        throw new Error('译员不存在');
      }
      const updatedTranslator = { 
        ...mockData.translators[index], 
        ...translatorData, 
        updatedAt: new Date().toISOString() 
      };
      mockData.translators[index] = updatedTranslator;
      return { success: true, data: updatedTranslator };
    }
    return apiClient.put<Translator>(`/translators/${id}`, translatorData);
  }
};

// 支付管理API
export const paymentApi = {
  async getPayments(params: QueryParams = {}): Promise<ApiResponse<Payment[]>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const { data, total } = applyFilters(mockData.payments, params);
      return {
        success: true,
        data,
        pagination: {
          page: params.page || 1,
          limit: params.limit || 10,
          total,
          totalPages: Math.ceil(total / (params.limit || 10))
        }
      };
    }
    return apiClient.get<Payment[]>('/payments', params);
  },

  async getPayment(id: string): Promise<ApiResponse<Payment>> {
    if (USE_MOCK_DATA) {
      await mockDelay(500);
      const payment = mockData.payments.find(p => p.id === id);
      if (!payment) {
        throw new Error('支付记录不存在');
      }
      return { success: true, data: payment };
    }
    return apiClient.get<Payment>(`/payments/${id}`);
  }
};

// 仪表板API
export const dashboardApi = {
  async getStats(): Promise<ApiResponse<DashboardStats>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      return { success: true, data: mockData.dashboardStats };
    }
    return apiClient.get<DashboardStats>('/dashboard/stats');
  },

  async getDashboardStats(): Promise<any> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      return mockData.dashboardStats;
    }
    const response = await apiClient.get<DashboardStats>('/dashboard/stats');
    return response.data;
  },

  async getRecentActivities(): Promise<any[]> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      return mockData.recentActivities || [];
    }
    const response = await apiClient.get<any[]>('/dashboard/activities');
    return response.data || [];
  },

  async getDashboardTrends(): Promise<any> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      return {
        callTrends: mockData.callTrends || [],
        revenueTrends: mockData.revenueTrends || [],
        languageDistribution: mockData.languageDistribution || []
      };
    }
    const response = await apiClient.get<any>('/dashboard/trends');
    return response.data;
  },

  async getChartData(period: string = '7d'): Promise<ApiResponse<ChartData[]>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      return { success: true, data: mockData.chartData };
    }
    return apiClient.get<ChartData[]>('/dashboard/chart', { period });
  }
};

// 系统设置API
export const settingsApi = {
  async getSettings(): Promise<ApiResponse<SystemSettings>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      return { success: true, data: mockData.systemSettings };
    }
    return apiClient.get<SystemSettings>('/settings');
  },

  async updateSettings(settings: Partial<SystemSettings>): Promise<ApiResponse<SystemSettings>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const updatedSettings = { 
        ...mockData.systemSettings, 
        ...settings, 
        updatedAt: new Date().toISOString() 
      };
      Object.assign(mockData.systemSettings, updatedSettings);
      return { success: true, data: updatedSettings };
    }
    return apiClient.put<SystemSettings>('/settings', settings);
  }
};

// 通知API
export const notificationApi = {
  async getNotifications(params: QueryParams = {}): Promise<ApiResponse<Notification[]>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const { data, total } = applyFilters(mockData.notifications, params);
      return {
        success: true,
        data,
        pagination: {
          page: params.page || 1,
          limit: params.limit || 10,
          total,
          totalPages: Math.ceil(total / (params.limit || 10))
        }
      };
    }
    return apiClient.get<Notification[]>('/notifications', params);
  },

  async markAsRead(id: string): Promise<ApiResponse<void>> {
    if (USE_MOCK_DATA) {
      await mockDelay(300);
      const notification = mockData.notifications.find(n => n.id === id);
      if (notification) {
        notification.read = true;
        notification.updatedAt = new Date().toISOString();
      }
      return { success: true, data: undefined };
    }
    return apiClient.put<void>(`/notifications/${id}/read`);
  },

  async markAllAsRead(): Promise<ApiResponse<void>> {
    if (USE_MOCK_DATA) {
      await mockDelay(500);
      mockData.notifications.forEach(notification => {
        notification.read = true;
        notification.updatedAt = new Date().toISOString();
      });
      return { success: true, data: undefined };
    }
    return apiClient.put<void>('/notifications/read-all');
  }
};

// 系统日志API
export const logApi = {
  async getLogs(params: QueryParams = {}): Promise<ApiResponse<SystemLog[]>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const { data, total } = applyFilters(mockData.systemLogs, params);
      return {
        success: true,
        data,
        pagination: {
          page: params.page || 1,
          limit: params.limit || 10,
          total,
          totalPages: Math.ceil(total / (params.limit || 10))
        }
      };
    }
    return apiClient.get<SystemLog[]>('/logs', params);
  }
};

// 认证API
export const authApi = {
  async login(email: string, password: string): Promise<ApiResponse<{ user: User; token: string }>> {
    if (USE_MOCK_DATA) {
      await mockDelay();
      const user = mockData.users.find(u => u.email === email);
      if (!user || password !== 'password') {
        throw new Error('邮箱或密码错误');
      }
      const token = `mock_token_${user.id}_${Date.now()}`;
      apiClient.setToken(token);
      return { success: true, data: { user, token } };
    }
    const response = await apiClient.post<{ user: User; token: string }>('/auth/login', { email, password });
    if (response.success && response.data) {
      apiClient.setToken(response.data.token);
    }
    return response;
  },

  async logout(): Promise<ApiResponse<void>> {
    if (USE_MOCK_DATA) {
      await mockDelay(300);
      apiClient.removeToken();
      return { success: true, data: undefined };
    }
    const response = await apiClient.post<void>('/auth/logout');
    apiClient.removeToken();
    return response;
  },

  async getCurrentUser(): Promise<ApiResponse<User>> {
    if (USE_MOCK_DATA) {
      await mockDelay(500);
      const token = localStorage.getItem('token');
      if (!token) {
        throw new Error('未登录');
      }
      const userId = token.split('_')[2];
      const user = mockData.users.find(u => u.id === userId) || mockData.users[0];
      return { success: true, data: user };
    }
    return apiClient.get<User>('/auth/me');
  }
};

// 导出API客户端
export { apiClient };

// 导出所有API
export default {
  user: userApi,
  call: callApi,
  document: documentApi,
  appointment: appointmentApi,
  translator: translatorApi,
  payment: paymentApi,
  dashboard: dashboardApi,
  settings: settingsApi,
  notification: notificationApi,
  log: logApi,
  auth: authApi
};

// 统一的 apiService 导出，用于向后兼容
export const apiService = {
  getDashboardStats: dashboardApi.getDashboardStats,
  getRecentActivities: dashboardApi.getRecentActivities,
  getDashboardTrends: dashboardApi.getDashboardTrends,
  getCalls: callApi.getCalls,
  deleteCall: callApi.deleteCall,
  batchDeleteCalls: callApi.batchDeleteCalls,
  getCallRecordingUrl: callApi.getCallRecordingUrl
};