import { createContext, useContext, useReducer, ReactNode, Dispatch } from 'react';
import { User, SystemSettings, Notification } from '@/types';
import { storage } from '@/utils';
import { STORAGE_KEYS } from '@/constants';

// 应用状态接口
export interface AppState {
  user: User | null;
  isAuthenticated: boolean;
  token: string | null;
  theme: 'light' | 'dark';
  sidebarCollapsed: boolean;
  loading: boolean;
  systemSettings: SystemSettings | null;
  notifications: Notification[];
  unreadCount: number;
  error: string | null;
  message: string | null;
}

// 初始状态
const initialState: AppState = {
  user: {
    id: '1',
    name: '管理员',
    email: 'admin@example.com',
    phone: '13800138000',
    role: 'admin',
    status: 'active',
    createdAt: new Date().toISOString(),
    updatedAt: new Date().toISOString(),
    lastLoginAt: new Date().toISOString(),
    preferences: {
      language: 'zh-CN',
      timezone: 'Asia/Shanghai',
      notifications: {
        email: true,
        sms: true,
        push: true,
      },
      theme: 'light',
    },
  },
  isAuthenticated: true,
  token: storage.get(STORAGE_KEYS.TOKEN) || 'temp-token',
  theme: storage.get(STORAGE_KEYS.THEME) || 'light',
  sidebarCollapsed: storage.get(STORAGE_KEYS.SIDEBAR_COLLAPSED) || false,
  loading: false,
  systemSettings: null,
  notifications: [],
  unreadCount: 0,
  error: null,
  message: null,
};

// 动作类型
export type AppAction =
  | { type: 'SET_USER'; payload: User | null }
  | { type: 'SET_AUTHENTICATED'; payload: boolean }
  | { type: 'SET_TOKEN'; payload: string | null }
  | { type: 'LOGIN_SUCCESS'; payload: { user: User; token: string } }
  | { type: 'LOGOUT' }
  | { type: 'SET_THEME'; payload: 'light' | 'dark' }
  | { type: 'TOGGLE_THEME' }
  | { type: 'SET_SIDEBAR_COLLAPSED'; payload: boolean }
  | { type: 'TOGGLE_SIDEBAR' }
  | { type: 'SET_LOADING'; payload: boolean }
  | { type: 'SET_SYSTEM_SETTINGS'; payload: SystemSettings }
  | { type: 'SET_NOTIFICATIONS'; payload: Notification[] }
  | { type: 'ADD_NOTIFICATION'; payload: Notification }
  | { type: 'REMOVE_NOTIFICATION'; payload: string }
  | { type: 'MARK_NOTIFICATION_READ'; payload: string }
  | { type: 'MARK_ALL_NOTIFICATIONS_READ' }
  | { type: 'SET_UNREAD_COUNT'; payload: number }
  | { type: 'SET_ERROR'; payload: string | null }
  | { type: 'SET_MESSAGE'; payload: string | null }
  | { type: 'CLEAR_ERROR' }
  | { type: 'CLEAR_MESSAGE' };

// Reducer函数
const appReducer = (state: AppState, action: AppAction): AppState => {
  switch (action.type) {
    case 'SET_USER':
      return { ...state, user: action.payload };
      
    case 'SET_AUTHENTICATED':
      return { ...state, isAuthenticated: action.payload };
      
    case 'SET_TOKEN':
      if (action.payload) {
        storage.set(STORAGE_KEYS.TOKEN, action.payload);
      } else {
        storage.remove(STORAGE_KEYS.TOKEN);
      }
      return { ...state, token: action.payload };
      
    case 'LOGIN_SUCCESS':
      storage.set(STORAGE_KEYS.TOKEN, action.payload.token);
      return {
        ...state,
        user: action.payload.user,
        token: action.payload.token,
        isAuthenticated: true,
        error: null,
      };
      
    case 'LOGOUT':
      storage.remove(STORAGE_KEYS.TOKEN);
      return {
        ...state,
        user: null,
        token: null,
        isAuthenticated: false,
        notifications: [],
        unreadCount: 0,
      };

    case 'SET_THEME':
      storage.set(STORAGE_KEYS.THEME, action.payload);
      return { ...state, theme: action.payload };
      
    case 'TOGGLE_THEME':
      const newTheme = state.theme === 'light' ? 'dark' : 'light';
      storage.set(STORAGE_KEYS.THEME, newTheme);
      return { ...state, theme: newTheme };
      
    case 'SET_SIDEBAR_COLLAPSED':
      storage.set(STORAGE_KEYS.SIDEBAR_COLLAPSED, action.payload);
      return { ...state, sidebarCollapsed: action.payload };
      
    case 'TOGGLE_SIDEBAR':
      const collapsed = !state.sidebarCollapsed;
      storage.set(STORAGE_KEYS.SIDEBAR_COLLAPSED, collapsed);
      return { ...state, sidebarCollapsed: collapsed };
      
    case 'SET_LOADING':
      return { ...state, loading: action.payload };

    case 'SET_SYSTEM_SETTINGS':
      return { ...state, systemSettings: action.payload };

    case 'SET_NOTIFICATIONS':
      const unreadCount = action.payload.filter(n => !n.read).length;
      return { 
        ...state, 
        notifications: action.payload,
        unreadCount 
      };
      
    case 'ADD_NOTIFICATION':
      const newNotifications = [action.payload, ...state.notifications];
      const newUnreadCount = newNotifications.filter(n => !n.read).length;
      return { 
        ...state, 
        notifications: newNotifications,
        unreadCount: newUnreadCount 
      };
      
    case 'REMOVE_NOTIFICATION':
      const filteredNotifications = state.notifications.filter(n => n.id !== action.payload);
      const filteredUnreadCount = filteredNotifications.filter(n => !n.read).length;
      return { 
        ...state, 
        notifications: filteredNotifications,
        unreadCount: filteredUnreadCount 
      };
      
    case 'MARK_NOTIFICATION_READ':
      const updatedNotifications = state.notifications.map(n =>
        n.id === action.payload ? { ...n, read: true } : n
      );
      const updatedUnreadCount = updatedNotifications.filter(n => !n.read).length;
      return { 
        ...state, 
        notifications: updatedNotifications,
        unreadCount: updatedUnreadCount 
      };
      
    case 'MARK_ALL_NOTIFICATIONS_READ':
      const allReadNotifications = state.notifications.map(n => ({ ...n, read: true }));
      return { 
        ...state, 
        notifications: allReadNotifications,
        unreadCount: 0 
      };
      
    case 'SET_UNREAD_COUNT':
      return { ...state, unreadCount: action.payload };

    case 'SET_ERROR':
      return { ...state, error: action.payload };
      
    case 'SET_MESSAGE':
      return { ...state, message: action.payload };
      
    case 'CLEAR_ERROR':
      return { ...state, error: null };
      
    case 'CLEAR_MESSAGE':
      return { ...state, message: null };

    default:
      return state;
  }
};

// Context接口
interface AppContextType {
  state: AppState;
  dispatch: Dispatch<AppAction>;
}

// Context
const AppContext = createContext<AppContextType | null>(null);

// Provider组件
interface AppProviderProps {
  children: ReactNode;
}

export const AppProvider = ({ children }: AppProviderProps) => {
  const [state, dispatch] = useReducer(appReducer, initialState);

  return (
    <AppContext.Provider value={{ state, dispatch }}>
      {children}
    </AppContext.Provider>
  );
};

// 自定义Hook
export const useAppState = () => {
  const context = useContext(AppContext);
  if (!context) {
    throw new Error('useAppState must be used within an AppProvider');
  }
  return context;
};

// 便捷的状态和动作Hooks
export const useAuth = () => {
  const { state, dispatch } = useAppState();
  
  const login = (user: User, token: string) => {
    dispatch({ type: 'LOGIN_SUCCESS', payload: { user, token } });
  };
  
  const logout = () => {
    dispatch({ type: 'LOGOUT' });
  };
  
  const setUser = (user: User | null) => {
    dispatch({ type: 'SET_USER', payload: user });
  };
  
  return {
    user: state.user,
    token: state.token,
    isAuthenticated: state.isAuthenticated,
    login,
    logout,
    setUser,
  };
};

export const useTheme = () => {
  const { state, dispatch } = useAppState();
  
  const setTheme = (theme: 'light' | 'dark') => {
    dispatch({ type: 'SET_THEME', payload: theme });
  };
  
  const toggleTheme = () => {
    dispatch({ type: 'TOGGLE_THEME' });
  };
  
  return {
    theme: state.theme,
    setTheme,
    toggleTheme,
  };
};

export const useSidebar = () => {
  const { state, dispatch } = useAppState();
  
  const setSidebarCollapsed = (collapsed: boolean) => {
    dispatch({ type: 'SET_SIDEBAR_COLLAPSED', payload: collapsed });
  };
  
  const toggleSidebar = () => {
    dispatch({ type: 'TOGGLE_SIDEBAR' });
  };
  
  return {
    sidebarCollapsed: state.sidebarCollapsed,
    setSidebarCollapsed,
    toggleSidebar,
  };
};

export const useNotifications = () => {
  const { state, dispatch } = useAppState();
  
  const setNotifications = (notifications: Notification[]) => {
    dispatch({ type: 'SET_NOTIFICATIONS', payload: notifications });
  };
  
  const addNotification = (notification: Notification) => {
    dispatch({ type: 'ADD_NOTIFICATION', payload: notification });
  };
  
  const removeNotification = (id: string) => {
    dispatch({ type: 'REMOVE_NOTIFICATION', payload: id });
  };
  
  const markAsRead = (id: string) => {
    dispatch({ type: 'MARK_NOTIFICATION_READ', payload: id });
  };
  
  const markAllAsRead = () => {
    dispatch({ type: 'MARK_ALL_NOTIFICATIONS_READ' });
  };
  
  return {
    notifications: state.notifications,
    unreadCount: state.unreadCount,
    setNotifications,
    addNotification,
    removeNotification,
    markAsRead,
    markAllAsRead,
  };
};

export const useLoading = () => {
  const { state, dispatch } = useAppState();
  
  const setLoading = (loading: boolean) => {
    dispatch({ type: 'SET_LOADING', payload: loading });
  };
  
  return {
    loading: state.loading,
    setLoading,
  };
};

export const useMessages = () => {
  const { state, dispatch } = useAppState();
  
  const setError = (error: string | null) => {
    dispatch({ type: 'SET_ERROR', payload: error });
  };
  
  const setMessage = (message: string | null) => {
    dispatch({ type: 'SET_MESSAGE', payload: message });
  };
  
  const clearError = () => {
    dispatch({ type: 'CLEAR_ERROR' });
  };
  
  const clearMessage = () => {
    dispatch({ type: 'CLEAR_MESSAGE' });
  };
  
  return {
    error: state.error,
    message: state.message,
    setError,
    setMessage,
    clearError,
    clearMessage,
  };
};

export const useSystemSettings = () => {
  const { state, dispatch } = useAppState();
  
  const setSystemSettings = (settings: SystemSettings) => {
    dispatch({ type: 'SET_SYSTEM_SETTINGS', payload: settings });
  };
  
  return {
    systemSettings: state.systemSettings,
    setSystemSettings,
  };
}; 