// 用户相关类型
export interface User {
  id: string;
  email: string;
  name: string;
  phone: string;
  avatar?: string;
  role: 'user' | 'admin' | 'translator';
  status: 'active' | 'inactive' | 'suspended';
  createdAt: string;
  updatedAt: string;
  lastLoginAt?: string;
  preferences: UserPreferences;
  subscription?: Subscription;
}

export interface UserPreferences {
  language: string;
  timezone: string;
  notifications: {
    email: boolean;
    sms: boolean;
    push: boolean;
  };
  theme: 'light' | 'dark' | 'auto';
}

// 订阅相关类型
export interface Subscription {
  id: string;
  userId: string;
  plan: 'free' | 'basic' | 'premium' | 'enterprise';
  status: 'active' | 'cancelled' | 'expired';
  startDate: string;
  endDate: string;
  features: string[];
  paymentMethod?: PaymentMethod;
}

export interface PaymentMethod {
  id: string;
  type: 'card' | 'paypal' | 'bank';
  last4?: string;
  brand?: string;
  expiryMonth?: number;
  expiryYear?: number;
}

// 翻译服务类型
export interface TranslationCall {
  id: string;
  callId?: string;
  userId: string;
  clientName?: string;
  clientPhone?: string;
  type: 'ai' | 'human' | 'video' | 'sign';
  status: 'pending' | 'active' | 'completed' | 'cancelled';
  sourceLanguage: string;
  targetLanguage: string;
  startTime: string;
  endTime?: string;
  duration?: number;
  cost: number;
  rating?: number;
  feedback?: string;
  translatorId?: string;
  translatorName?: string;
  translatorPhone?: string;
  recordingUrl?: string;
  transcription?: string;
  translation?: string;
}

// Call 类型别名（向后兼容）
export type Call = TranslationCall;

// 文档翻译类型
export interface DocumentTranslation {
  id: string;
  userId: string;
  fileName: string;
  fileSize: number;
  fileType: string;
  fileUrl: string;
  translatedFileUrl?: string;
  sourceLanguage: string;
  targetLanguage: string;
  status: 'uploading' | 'pending' | 'processing' | 'completed' | 'failed' | 'review';
  progress: number;
  cost: number;
  pageCount?: number;
  wordCount?: number;
  translatorId?: string;
  createdAt: string;
  updatedAt: string;
  completedAt?: string;
  quality?: 'draft' | 'professional' | 'certified';
}

// 预约类型
export interface Appointment {
  id: string;
  userId: string;
  translatorId?: string;
  title: string;
  description: string;
  type: 'ai' | 'human' | 'video' | 'sign';
  sourceLanguage: string;
  targetLanguage: string;
  startTime: string;
  endTime: string;
  status: 'scheduled' | 'confirmed' | 'cancelled' | 'completed';
  cost: number;
  meetingUrl?: string;
  notes?: string;
  reminderSent: boolean;
  createdAt: string;
  updatedAt: string;
}

// 译员类型
export interface Translator {
  id: string;
  userId: string;
  name: string;
  email: string;
  phone: string;
  avatar?: string;
  languages: Language[];
  specializations: string[];
  rating: number;
  totalCalls: number;
  totalHours: number;
  hourlyRate: number;
  status: 'available' | 'busy' | 'offline';
  certifications: Certification[];
  experience: number;
  bio?: string;
  workingHours: WorkingHours;
  createdAt: string;
  updatedAt: string;
}

export interface Language {
  code: string;
  name: string;
  level: 'native' | 'fluent' | 'intermediate' | 'basic';
}

export interface Certification {
  id: string;
  name: string;
  issuer: string;
  issueDate: string;
  expiryDate?: string;
  credentialUrl?: string;
}

export interface WorkingHours {
  monday: TimeSlot[];
  tuesday: TimeSlot[];
  wednesday: TimeSlot[];
  thursday: TimeSlot[];
  friday: TimeSlot[];
  saturday: TimeSlot[];
  sunday: TimeSlot[];
}

export interface TimeSlot {
  start: string;
  end: string;
}

// 支付相关类型
export interface Payment {
  id: string;
  userId: string;
  amount: number;
  currency: string;
  status: 'pending' | 'completed' | 'failed' | 'refunded';
  type: 'call' | 'document' | 'subscription';
  referenceId: string;
  paymentMethod: PaymentMethod;
  createdAt: string;
  updatedAt: string;
  stripePaymentIntentId?: string;
}

// 统计数据类型
export interface DashboardStats {
  totalUsers: number;
  activeUsers: number;
  totalCalls: number;
  totalDocuments: number;
  totalRevenue: number;
  averageRating: number;
  callsToday: number;
  documentsToday: number;
  revenueToday: number;
  userGrowth: number;
  callsGrowth: number;
  revenueGrowth: number;
}

export interface ChartData {
  date: string;
  users: number;
  calls: number;
  documents: number;
  revenue: number;
}

// API响应类型
export interface ApiResponse<T> {
  success: boolean;
  data?: T;
  message?: string;
  error?: string;
  pagination?: PaginationInfo;
}

export interface PaginationInfo {
  page: number;
  limit: number;
  total: number;
  totalPages: number;
}

// 表格查询参数类型
export interface QueryParams {
  page?: number;
  limit?: number;
  search?: string;
  sortBy?: string;
  sortOrder?: 'asc' | 'desc';
  status?: string;
  dateFrom?: string;
  dateTo?: string;
  [key: string]: any;
}

// 系统设置类型
export interface SystemSettings {
  id: string;
  siteName: string;
  siteDescription: string;
  logo?: string;
  favicon?: string;
  supportEmail: string;
  languages: Language[];
  defaultLanguage: string;
  timezone: string;
  currency: string;
  features: {
    aiTranslation: boolean;
    humanTranslation: boolean;
    videoCall: boolean;
    documentTranslation: boolean;
    appointmentBooking: boolean;
  };
  pricing: {
    aiCallPerMinute: number;
    humanCallPerMinute: number;
    videoCallPerMinute: number;
    documentPerPage: number;
  };
  limits: {
    freeCallsPerMonth: number;
    maxFileSize: number;
    maxDocumentPages: number;
  };
  integrations: {
    twilio: {
      enabled: boolean;
      accountSid?: string;
      authToken?: string;
    };
    stripe: {
      enabled: boolean;
      publishableKey?: string;
      secretKey?: string;
    };
    openai: {
      enabled: boolean;
      apiKey?: string;
    };
  };
  createdAt: string;
  updatedAt: string;
}

// 通知类型
export interface Notification {
  id: string;
  userId?: string;
  type: 'info' | 'success' | 'warning' | 'error';
  title: string;
  message: string;
  read: boolean;
  createdAt: string;
  updatedAt: string;
  actionUrl?: string;
  actionText?: string;
}

// 日志类型
export interface SystemLog {
  id: string;
  level: 'info' | 'warn' | 'error' | 'debug';
  message: string;
  userId?: string;
  action?: string;
  resource?: string;
  resourceId?: string;
  ip?: string;
  userAgent?: string;
  metadata?: Record<string, any>;
  createdAt: string;
}

// 表单类型
export interface LoginForm {
  email: string;
  password: string;
  remember?: boolean;
}

export interface UserForm {
  name: string;
  email: string;
  phone: string;
  role: 'user' | 'admin' | 'translator';
  status: 'active' | 'inactive' | 'suspended';
  password?: string;
}

export interface TranslatorForm {
  name: string;
  email: string;
  phone: string;
  languages: Language[];
  specializations: string[];
  hourlyRate: number;
  bio?: string;
  experience: number;
  certifications: Certification[];
}

export interface AppointmentForm {
  title: string;
  description: string;
  type: 'ai' | 'human' | 'video' | 'sign';
  sourceLanguage: string;
  targetLanguage: string;
  startTime: string;
  endTime: string;
  translatorId?: string;
}

// 菜单类型
export interface MenuItem {
  key: string;
  label: string;
  icon?: React.ReactNode;
  path?: string;
  children?: MenuItem[];
  permission?: string;
}

// 权限类型
export interface Permission {
  id: string;
  name: string;
  description: string;
  resource: string;
  action: string;
}

export interface Role {
  id: string;
  name: string;
  description: string;
  permissions: Permission[];
  createdAt: string;
  updatedAt: string;
} 